;@***h* MLT_V4_RSS/fix_noaa_crossing_time_data.pro
; NAME
;	fix_noaa_crossing_time_data.pro
;
; PURPOSE
;	fixes errors in navigation files
;
; DESCRIPTION
;	top level IDL script to fix errors in navigation files.  The program functions by looking for anomalous jumps in the a value
;     The a parameter, which is the difference between the eqx time and orbit_number*orbital_period should evolve smoothly.  
;     Various idiosyncratic approaches are used for specific satellites.
;
; INPUTS
;	The satellite number should be set in the 2nd line of code.
;
; OUTPUTS
;	  
;
; AUTHOR
;	Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;	THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;	THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;	AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;	AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;	SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;	THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT TO USERS.
;
; HISTORY
;	4/10/2018 Initial Version prepared for NCEI
;
; USAGE
;	.r fix_noaa_crossing_time_data.pro
;
;@*****


MSU_ORBIT_TIME = 0.070799d0
sat_num = 4
fill_in_large_gaps =    [0,1,0,1,0,0,1,1,0]
use_old_rss_inventory = [0,0,0,1,1,0,1,1,1]


type = 'noaa_raw'
if sat_num lt 8 then begin
  read_MSU_nav_file,sat_num,eqx_time,eqx_lon,a,orbit_valid,error,type = type
endif

if (use_old_rss_inventory[sat_num]) then begin
  read_L2A_inventory,sat_num+1,2,rss_exists,rss_start_scan,rss_end_scan,rss_start_rd_2000,rss_end_rd_2000,rss_eqx_rd_2000
  ;(read_L2A_inventory is in B:\idl_library\MSU_Utilities)
  if sat_num eq 3 then begin
    rss_eqx_rd_2000 = [dblarr(399),rss_eqx_rd_2000]
    a_rss = fltarr(100000L)
    orbit_num = findgen(100000L)
    a_rss = rss_eqx_rd_2000 - orbit_num*MSU_ORBIT_TIME
  endif
  
  if sat_num eq 4 then begin
    rss_eqx_rd_2000 = [replicate(!values.d_nan,43),rss_eqx_rd_2000]
    a_rss = fltarr(100000L)
    orbit_num = findgen(100000L)
    a_rss = rss_eqx_rd_2000 - orbit_num*MSU_ORBIT_TIME
    a[0:1050] = a_rss[0:1050] + 7.9042092e-006
  endif
  
  if sat_num eq 6 then begin
    rss_eqx_rd_2000 = [dblarr(45),rss_eqx_rd_2000]
    a_rss = fltarr(100000L)
    orbit_num = findgen(100000L)
    a_rss = rss_eqx_rd_2000 - orbit_num*MSU_ORBIT_TIME
    a_rss[40000L:60000L] = a_rss[40000L:60000L]+1.08
    a[40000L:60000L] = a_rss[40000L:60000L]
  endif
  if sat_num eq 7 then begin
    rss_eqx_rd_2000 = [dblarr(40),rss_eqx_rd_2000]
    a_rss = fltarr(100000L)
    orbit_num = findgen(100000L)
    a_rss = rss_eqx_rd_2000 - orbit_num*MSU_ORBIT_TIME
    rss_helps = where((finite(a_rss) eq 1) and (finite(a) eq 0))
    a[rss_helps] =a_rss[rss_helps]
    bad = where(a gt -2000.0D0)
    a[bad] = !values.f_nan
  endif
  if sat_num eq 8 then begin
    rss_eqx_rd_2000 = [replicate(!values.d_nan,22),rss_eqx_rd_2000]
    a_rss = fltarr(100000L)
    orbit_num = findgen(100000L)
    a_rss = rss_eqx_rd_2000 - orbit_num*MSU_ORBIT_TIME
    a = replicate(!values.d_nan,100000L)
    rss_helps = where(finite(a_rss) eq 1)
    a[rss_helps] = a_rss[rss_helps]
    a[19218:80000L] = a[19218:80000L] - MSU_ORBIT_TIME
    a[19090:19217]  = a[19090:19217] - MSU_ORBIT_TIME/2.
    orbit_valid = intarr(100000L)
    eqx_lon = dblarr(100000L)
  endif
endif

window,2
plot,a
oplot,a_rss,color=40

max_orbit = max(where(finite(a) eq 1))
min_orbit = min(where(finite(a) eq 1))


; look for anomalous jumps in a
a_interp = 0.5*([0,a[0:99998L]] + [a[1:99999L],0])
suspect = where(abs(a - a_interp) gt 0.0003,ct)

print,'found ',ct,'suspect a values'

a_adjusted = a
a_adjusted[suspect] = !values.d_nan
if sat_num eq 4 then  a_adjusted[10933:10939] = !values.d_nan
a_adjusted2 = a_adjusted
num_orbits= n_elements(a_adjusted)

for i = 0L,min([max_orbit + 50,num_orbits]) - 1L do begin
  if ((i mod 1000) eq 0) then print, i
  if finite(a_adjusted2[i]) eq 0 then begin
    if i gt 4139 then begin
      print
    endif
    begin_i = max([0,i-50])
    end_i = min([num_orbits-1,i+50])
    
    subset = a_adjusted[begin_i:end_i]
    orbit_nums = begin_i + dindgen(1+begin_i+end_i)
    
    ok = where(finite(subset) eq 1,ct)
    if ct gt 10 then begin
      fit = linfit(orbit_nums[ok],subset[ok])
      a_adjusted2[i] = fit[0] + fit[1]*i
      orbit_valid[i] = 2
    endif   
  endif
endfor

ok = where(finite(a_adjusted2) eq 1)
first_valid_a_loc = min(ok)
last_valid_a_loc = max(ok)


if fill_in_large_gaps[sat_num] gt 0 then begin
  a_adjusted3 = a_adjusted2
  if sat_num eq 1 then a_adjusted3 = a_adjusted2[0:36999L]
  i = dindgen(55000)
  ok = where(finite(a_adjusted3) eq 1)
  fit = poly_fit(i[ok],a_adjusted3[ok],5)
  i = dindgen(60000)
  fitted_values = fit[0] + i*fit[1] + i*i*fit[2]+ i*i*i*fit[3]+i*i*i*i*fit[4]+i*i*i*i*i*fit[5]
  
  places_to_fill = where((i ge first_valid_a_loc) and (i le last_valid_a_loc) and (finite(a_adjusted2) eq 0),ct)
  
  a_adjusted2[places_to_fill] = fitted_values[places_to_fill]
endif

window,2
plot,a
oplot,a_adjusted2,color=200
eqx_time_adj = replicate(!values.d_nan,num_orbits)

for i = 0L,min([max_orbit + 50,num_orbits]) - 1L do begin
    eqx_time_adj[i] = a_adjusted2[i] + MSU_ORBIT_TIME*i 
endfor


ok = where((finite(eqx_time_adj) eq 1) and (orbit_valid eq 0),ct)
if ct gt 0 then orbit_valid[ok] = 2
write_MSU_nav_file,sat_num,eqx_time_adj,eqx_lon,a_adjusted2,orbit_valid,type = 'noaa_fixed',error


end

