;@***h* MLT_V4_RSS/median_linfit.pro
; NAME
;	median_linfit.pro
;
; PURPOSE
;	calculates the median slope of 300 random intervals for the given x,y series
;
; DESCRIPTION
;	calculates the median slope of 300 random intervals for the given x,y series
;
; INPUTS
;	x	real,dimension(nx)	array of x values.  Should be larger than 20 values
;	y  	real,dimension(ny)	array of y values.  Should be larger than 20 values
;
; OUTPUTS
;	return value	real,dimension(2)		median of slopes and intercepts of random segments 
;
; AUTHOR
;	Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;	THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;	THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;	AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;	AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;	SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;	THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT TO USERS.
;
; HISTORY
;	4/10/2018 Initial Version prepared for NCEI
;
; USAGE
;	median_parameters = median_linfit(x,y)
;
;@*****

function median_linfit,x,y

  common seed,seed
  
  if keyword_set(seed) eq 0 then seed = 1345L

  nx = n_elements(x)
  ny = n_elements(y)
  
  if nx ne ny then begin
    print,'Error -- array lengths do not match'
    return,replicate(!values.f_nan,2)
  endif
  
  if nx lt 20 then begin
    print,'Warning -- median method not recommended
  endif
  
  
  num_slopes = 300
  
  index_1 = floor(nx*randomu(seed,floor(1.1*num_slopes)))
  index_2 = floor(nx*randomu(seed,floor(1.1*num_slopes)))
  ok = where(index_1 ne index_2,ct)
  if ct ge num_slopes then begin
    index_1 =  index_1[ok[0:num_slopes-1]]
    index_2 =  index_2[ok[0:num_slopes-1]]
  endif else begin
    print, 'unlikely error!
    stop
  endelse
  
  slope_arr = (y[index_1] - y[index_2])/(x[index_1] - x[index_2])
  ok = where(finite(slope_arr) eq 1,ct)
  if ct gt 0 then begin
    med_slope = median(slope_arr[ok],/even)
    b = y[ok] - med_slope*x[ok]
    ok2 = where(finite(b) eq 1,ct2)
    if ct2 gt 0 then begin
      med_intercept = median(b[ok2],/even)
    endif else begin
      med_intercept = !values.f_nan
    endelse
  endif else begin
    med_slope = !values.f_nan
    med_intercept = !values.f_nan
  endelse
  
  return,[med_intercept,med_slope]
  
end