;@***h* MLT_V4_RSS/read_msu_raw_crossing_file.pro
; NAME
;	read_msu_raw_crossing_file.pro
;
; PURPOSE
;	reads "raw" or uncorrected MSU crossing time files
;
; DESCRIPTION
;	reads "raw" or uncorrected MSU crossing time files
;
; INPUTS
;	sat_num
;
; OUTPUTS
;	orbit_num		integer,dimension(0:max orbit)		orbit number
;	orbit_real		double,dimension(0:max orbit)			orbit number in double precision
;	eqx_time		double,dimension(0:max orbit)			equator crossing time
;	a			double,dimension(0:max orbit)			equator crossing time - orbit_number*orbital_period
;	eqx_long		double,dimension(0:max orbit)			equator crossing longitude
;
; AUTHOR
;	Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;	THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;	THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;	AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;	AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;	SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;	THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT TO USERS.
;
; HISTORY
;	4/10/2018 Initial Version prepared for NCEI
;
; USAGE
;	read_msu_raw_crossing_file,sat_num,orbit_num,orbit_real,eqx_time,a,eqx_long

;
;@*****

pro read_msu_raw_crossing_file,sat_num,orbit_num,orbit_real,eqx_time,a,eqx_long

 log_path = 'm:\MSU_AMSU_Data\MSU_L1Bv2\'
 sat_names = ['TIROS-N','NOAA-06','NOAA-07','NOAA-08','NOAA-09','NOAA-10','NOAA-11','NOAA-12','NOAA-14']
 sat_name_short = ['tn','n6','n7','n8','n9','n10','n11','n12','n14']
     
 mx_orbits =  100000L

 eqx_time = replicate(!values.d_nan,mx_orbits)
 orbit_real  = replicate(!values.d_nan,mx_orbits)
 a        = replicate(!values.d_nan,mx_orbits)
 eqx_long = replicate(!values.d_nan,mx_orbits)
 orbit_num = lonarr(mx_orbits)

 xtime_file = log_path+sat_names[sat_num]+'\logs\'+sat_names[sat_num]+'_raw_crossings.txt'

 close,3
 openr,3,xtime_file

 on_ioerror,file_end

 MSU_ORBIT_TIME = 0.070799d0
 for i = 0,MX_ORBITS-1 do begin
   orbitx = 0L
   orbit_realx = 0.0D0
   eqxx = 0.0D0
   eqxlonx = 0.0D0
   ax = 0.0D0
   
   readf,3,orbitx,orbit_realx,eqxx,ax,eqxlonx, $
   format = '(i7,2x,f14.6,2x,f14.6,2x,f14.6,2x,f14.6)'
   
   if ((orbitx ge 0) and (orbitx le MX_ORBITS-1)) then begin
       if ((sat_num eq 1) and (orbitx gt 37750)) then begin
         orbitx = orbitx+1
         ax = ax - MSU_ORBIT_TIME
       endif
       eqx_time[orbitx] = eqxx
       eqx_long[orbitx] = eqxlonx
       a[orbitx] = ax
       orbit_real[orbitx] = orbit_realx
       orbit_num[orbitx] = orbitx
    endif
 endfor


 file_end:
 close,3

 ok = where(finite(eqx_time) eq 1,ct)
 mx_orbit = max(ok)

 a = a[0:mx_orbit]
 orbit_real = orbit_real[0:mx_orbit]
 eqx_time = eqx_time[0:mx_orbit]
 eqx_long = eqx_long[0:mx_orbit]
 orbit_num = orbit_num[0:mx_orbit]

 return

end
