;@***h* MLT_V4_RSS/msu_l1b_ingest_driver
; NAME
;	msu_l1b_ingest_driver
;
; PURPOSE
;	top level driver script for ingesting MSU L1B files
;
; DESCRIPTION
;	top level driver script for ingesting MSU L1B files.
;
; INPUTS
;	set sat_num to desired satellite in code
;
; OUTPUTS
;	writes monthly L1B files with duplicated and erroneous records removed
;	writes updated navigation file that is corrected based on what is found in the MSU L1B files
;
; AUTHOR
;	Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;	THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;	THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;	AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;	AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;	SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;	THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT TO USERS.
;
; HISTORY
;	4/10/2018 Initial Version prepared for NCEI
;
; USAGE
;	top level program
;
;@*****

	program msu_l1b_ingest_driver

		use MSU_L1B_ingest
		use DFLIB
		use MSU_navigation

		logical								:: wrt
		logical								:: eval_crossing_only
		integer(4):: error,year,month,sat_num
		
		integer(4) :: first_year
		integer(4) :: last_year

		character(len=120)		:: buffer

		character(len=FILE_LEN)	:: MSU_INCOMING_PATH 

		wrt = .true.  ! set to true to write out results
		sat_num = 5
		
		select case (sat_num)
		    case(1) 
		        MSU_INCOMING_PATH = 'M:\MSU_AMSU_Data\MSU_L1A\TIROS-N\'
		        first_year = 1978
		        last_year = 1981
		    case(2)
		        MSU_INCOMING_PATH = 'M:\MSU_AMSU_Data\MSU_L1A\NOAA-6\'
		        first_year = 1979
		        last_year = 1986
		    case(3)
		        MSU_INCOMING_PATH = 'M:\MSU_AMSU_Data\MSU_L1A\NOAA-7\'
		        first_year = 1981
		        last_year = 1985
		    case(4)
		        MSU_INCOMING_PATH = 'M:\MSU_AMSU_Data\MSU_L1A\NOAA-8\'
		        first_year = 1983
		        last_year = 1985
		    case(5)
		        MSU_INCOMING_PATH = 'M:\MSU_AMSU_Data\MSU_L1A\NOAA-9\'
		        first_year = 1985
		        last_year = 1988	
		     case(6)
		        MSU_INCOMING_PATH = 'M:\MSU_AMSU_Data\MSU_L1A\NOAA-10\'
		        first_year = 1986
		        last_year = 1991	    
		     case(7)
		        MSU_INCOMING_PATH = 'M:\MSU_AMSU_Data\MSU_L1A\NOAA-11\'
		        first_year = 1988
		        last_year = 1999	
		     case(8)
		        MSU_INCOMING_PATH = 'M:\MSU_AMSU_Data\MSU_L1A\NOAA-12\'
		        first_year = 1991
		        last_year = 2001
		     case(9)
		        MSU_INCOMING_PATH = 'M:\MSU_AMSU_Data\MSU_L1A\NOAA-14\'
		        first_year = 1995 ! should be 1995
		        last_year = 2005  ! 2005
		    case default
		        print *,'Invalid Satellite Number'
		        stop
		end select
		

		call read_MSU_NOAA_nav_file(sat_num,error)

		do year = first_year,last_year
			do month = 1,12
		      	if ((sat_num .eq. 1) .and. (month .le. 10) .and. (year .eq. 1978)) cycle 
				call ingest_msu_l1b(MSU_INCOMING_PATH,sat_num,year,month,wrt,eval_crossing_only)
            	enddo
		enddo

		call write_MSU_RSS_nav_file(sat_num,error)

	end program msu_l1b_ingest_driver