;@***h* MLT_V4_RSS/assign_msu_height_driver.pro
; NAME
; assign_msu_height_driver.pro
;
; PURPOSE
; assigns satellite height to scans based on data from a table
;
; DESCRIPTION
; top level IDL script to fix errors in satellite height.  Heights are assigned to scans based on data from a table
;
; INPUTS
; The satellite number should be set in the 2nd line of code.
;
; OUTPUTS
; The program modifies the MSU L1B file so that it contains the corrected height in its navigation data
;
;
; AUTHOR
; Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
; THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
; THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
; AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
; AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
; SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
; THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT TO USERS.
;
; HISTORY
; 5/10/2018 Initial Version prepared for NCEI
;
; USAGE
; .r assign_msu_height_driver.pro
;
;@*****

for satnum = 5,5 do begin
satellite_name = sat_name(satnum,/fill)
case satnum of
  1: begin
    begin_year  = 1978
    end_year = 1981
    end
  2:begin
    begin_year = 1985;1979
    end_year = 1986
  end
  3:begin
    begin_year = 1981
    end_year = 1985
  end
  4:begin
    begin_year = 1983
    end_year = 1985
  end
  5:begin
    begin_year = 1985
    end_year = 1988
  end
  6:begin
    begin_year = 1986
    end_year = 1991
  end
  7:begin
    begin_year = 1988
    end_year = 1999
  end
  8:begin
    begin_year = 1991
    end_year = 1998
  end
  9:begin
    begin_year = 1995
    end_year = 2005
  end
    
endcase


for year_to_process = begin_year,end_year do begin
  for month_to_process = 1,12 do begin
     assign_corrected_msu_height,satellite_name,year_to_process,month_to_process,verbose=1
  endfor
endfor

endfor
                                             
end