;@***h* MLT_V4_RSS/write_msu_1lbv4_monthly_file.pro
; This file contains msu_l1bv4 write code
;
; NAME
; write_msu_L1Bv4_monthly_file
;
; PURPOSE
; creates and writes file with msu L1b data.
;
; DESCRIPTION
; creates and writes file with msu L1b data.
;
; INPUTS
; satellite_name       string containing satellite name
; year_to_read         integer containing the year to process
; month_to_read        integer containing the month to process
; level_string         string containing "level" of the L1B data.  
; msu_L1bv4            smu l1B data to write
;
; OUTPUTS
; error                 error flag.  Set to -1 if there is an error writing to the file.
; AUTHOR
; Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
; THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
; THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
; AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
; AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
; SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
; THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT TO USERS.
;
; HISTORY
; 5/10/2018 Initial Version prepared for NCEI
;
; USAGE
; write_msu_L1Bv4_monthly_file,'NOAA-06',1981,1,msu_L1bv4,'R3',error
   
;
;@*****

pro write_msu_L1Bv4_monthly_file,satellite_name,year,month,msu_L1bv4,level_string,error
    error = 0
    num_rssv4_scans = n_elements(msu_L1bv4)
    
    on_ioerror,file_error
    
    MSU_L1B_PATH = 'M:\MSU_AMSU_Data\MSU_L1Bv4\'
    filename = string(strtrim(MSU_L1B_PATH),satellite_name,satellite_name,year,month,level_string, $
    format = '(a,a,"\monthly\",a,"_monthly_L1B_",i4.4,"_",i2.2,"_",a,".dat")')
    close,3
    openw,3,filename
    for i = 0,num_rssv4_scans-1 do begin
      writeu,3,msu_L1bv4[i]
    endfor
    close,3
    return
    
    file_error:
      error = -1
      return
end
