module msu_l1b_to_l2a_monthly

		use MSU_Level_1B
		use MSU_Level_2A
		use nan_support
		use date_and_time
		use msu_types
		use msu_constants
		use msu_date
		use msu_l1b_Quality

		implicit none
		
		integer(4),dimension(32) :: flag_set_array

contains

;@***h* MLT_V4_RSS/process_msu_L1B_monthly_to_L2A
; NAME
;	process_msu_L1B_monthly_to_L2A
;
; PURPOSE
;	fill in purpose here
;
; DESCRIPTION
;	fill in description here
;
; INPUTS
;	sat_num
;	year
;	month
;	model_to_use
;
; OUTPUTS
;	sat_num
;	year
;	month
;	model_to_use
;
; AUTHOR
;	Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;	THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;	THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;	AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;	AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;	SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;	THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT TO USERS.
;
; HISTORY
;	4/10/2018 Initial Version prepared for NCEI
;
; USAGE
;	call subroutine process_msu_L1B_monthly_to_L2A(sat_num,year,month,model_to_use)

;
;@*****

subroutine process_msu_L1B_monthly_to_L2A(sat_num,year,month,model_to_use)

    integer(4)          :: sat_num
    integer(4)          :: year
    integer(4)          :: month
    character(10),intent(IN),OPTIONAL :: model_to_use
    
    type(msu_raw),dimension(MAX_SCANS_PER_MONTH)        :: msu_l1b_scan_array
    type(msu_L2A_scn),dimension(MAX_SCANS_PER_MONTH)    :: msu_l2a_scan_array
    
    character(len = FILE_LEN)				:: input_file	
    character(len = FILE_LEN)				:: log_file	
	character(len = FILE_LEN)               :: output_file
	character(len = 2)                      :: rev_string
	integer(4)                              :: read_status
	integer(4)                              :: qc_status
	
	integer(4)                              :: log_unit = 11
	
	
	character(len = 528)  :: scan_char_long_l1b  
	character(len = 1804) :: scan_char_long_l2a  
	
	integer(4)              :: num_scans,scan_num,num_scans_passed
	type(msu_raw)           :: msu_l1b_scan
	type(msu_L2A_scn)      :: msu_l2a_scan

    ! open the log file
    
     write(log_file,557)trim(MSU_L2A_PATH),sat_names_2(sat_num),sat_names_2(sat_num),year,month
     557   format(a,a,'\logs\',a,'_l1b_to_l2a_',i4.4,'_',i2.2,'.txt')
			open(unit=log_unit,file = log_file)

    
    
    ! read in L1B file
    
 
    rev_string = 'R3'
    write(input_file,601)trim(MSU_L1B_PATH),sat_names_2(sat_num),sat_names_2(sat_num),year,month,rev_string
601   format(a,a,'\monthly\',a,'_monthly_L1B_',i4.4,'_',i2.2,'_',a,'.dat')
    close(3)
    open(unit = 3,file = input_file,form='binary')
    
    write(log_unit,799)month,year
    write(6,799)month,year
    799 format('Converting L1B to L2a for ',i2.2,'/',i4.4)
    write(log_unit,881)input_file
    write(6,881)input_file
    881 format('Reading L1B File : ',a)
    read_status = 0
    scan_num = 1
    do while (read_status .eq. 0)
        read(3,iostat=read_status) scan_char_long_l1b 
        call decode_msu_l1b_orbit_file_scan_long(scan_char_long_l1b,msu_l1b_scan)
        if (read_status .eq. 0) then
            msu_l1b_scan_array(scan_num) = msu_l1b_scan
            scan_num = scan_num + 1
        endif
    enddo
    write(log_unit,882)scan_num
    write(6,882)scan_num
    882 format('Read',i7,' scans')  
    close(3)
    
    num_scans = scan_num
    
    if (num_scans .lt. 100) then
        write(log_unit,888)'Not enough scans to bother with'
        write(6,888)'Not enough scans to bother with'
        close(log_unit)
        return
    endif
    num_scans_passed = 0
    flag_set_array = 0
    write(log_unit,888)'Converting l1b to l2a and doing QC'
    write(6,888)'Converting l1b to l2a and doing QC'
      888 format(a)
    do scan_num = 1,num_scans
        if (modulo(scan_num,5000) .eq. 0) print *,scan_num

        ! perform calibration step  - counts to Tb, non-linearity and angle adjustments
        
        call msu_l1b_to_l2a(msu_l1b_scan_array(scan_num),msu_l2a_scan,model_to_use)
        
        
        ! do some quality control  - set scan qual and fov qual if there are any problems
        
        qc_status =  eval_l2a_quality(msu_l1b_scan_array(scan_num),msu_l2a_scan)
        msu_l2a_scan_array(scan_num) = msu_l2a_scan
        if (qc_status .eq. 0) num_scans_passed = num_Scans_passed+1
    enddo
    
    write(log_unit,883)num_Scans_passed
    write(6,883)num_Scans_passed
        883 format(i6,' scans passed L2A QC')  
    	        ! IBIT(0,1) = Earth Loc Delta
	        ! IBIT(1,1) = NO earth location
	        ! IBIT(6,1) = Data GAP
	        ! IBIT(7,1) = FATAL flag
	        ! IBIT(7,2) = Calibration Error for at least one channel
    write(log_unit,887)flag_set_array(1),'Earth Location Delta'
    write(log_unit,887)flag_set_array(2),'No Earth Location'
    write(log_unit,887)flag_set_array(3),'Data Gap'
    write(log_unit,887)flag_set_array(4),'Fatal Flag'
    write(log_unit,887)flag_set_array(5),'Calibration Error for at least one channel'
    write(log_unit,887)flag_set_array(8),'No Corrected Height'
    write(log_unit,887)flag_set_array(17),'Calibration Error Channel 1 (RSS Detected)'
    write(log_unit,887)flag_set_array(18),'Calibration Error Channel 2 (RSS Detected)'
    write(log_unit,887)flag_set_array(19),'Calibration Error Channel 3 (RSS Detected)'
    write(log_unit,887)flag_set_array(20),'Calibration Error Channel 4 (RSS Detected)'
 
    write(6,887)flag_set_array(1),'Earth Location Delta'
    write(6,887)flag_set_array(2),'No Earth Location'
    write(6,887)flag_set_array(3),'Data Gap'
    write(6,887)flag_set_array(4),'Fatal Flag'
    write(6,887)flag_set_array(5),'Calibration Error for at least one channel'
    write(6,887)flag_set_array(9),'No Corrected Height'
    write(6,887)flag_set_array(17),'Calibration Error Channel 1 (RSS Detected)'
    write(6,887)flag_set_array(18),'Calibration Error Channel 2 (RSS Detected)'
    write(6,887)flag_set_array(19),'Calibration Error Channel 3 (RSS Detected)'
    write(6,887)flag_set_array(20),'Calibration Error Channel 4 (RSS Detected)'
       887 format(i7,' failed: ',a)
    ! write out L2A file
    
    if (num_scans_passed .gt. 100) then
        rev_string = 'R3'
        write(output_file,901)trim(MSU_L2A_PATH),sat_names_2(sat_num),sat_names_2(sat_num),year,month,rev_string,TRIM(model_to_use)
            901   format(a,a,'\monthly\',a,'_monthly_l2a_',i4.4,'_',i2.2,'_',a,'.',a,'.dat')
        write(log_unit,884)output_file
        write(6,884)output_file
            884 format('Writing L2A File : ',a)
        
        open(unit = 3,file = output_file,form='binary')
        do scan_num = 1,num_scans
            ! encode structure to string
            call encode_msu_L2A_scan_long(msu_l2a_scan_array(scan_num),scan_char_long_l2a)   
            write(3) scan_char_long_l2a
        enddo
         
        close(3)
    endif
    close(log_unit)
    
    end subroutine process_msu_L1B_monthly_to_L2A
    
    
;@***h* MLT_V4_RSS/msu_l1b_to_l2a
; NAME
;	msu_l1b_to_l2a
;
; PURPOSE
;	performs the conversion from MSU L1B to MSU L2A
;
; DESCRIPTION
;	performs the conversion from MSU L1B to MSU L2A for a single scan.
;	The following steps are performed
;	1. orbit number, scan number, navigation and geolocation information are transfered to the L2A scan
;	2. calculate baseline non-linearity correction
;	3. calculate brightness temperatures for all channels
;	4. calculate EIA for all FOVs and channels, including the roll correction.
;	5. calculate incidence angle corrections
;	Note that corrections performed in step 5 are no longer used for TMT, TTS, and TLS.  For these channels, these corrections are
;	calculated later in the processing.  For TLT, the scan level corrections are still used.
;
; INPUTS
;	L1B_scan		type(msu_raw)	L1B scan information
;     model_to_use 	string		name of angle correction model to use.
;
; OUTPUTS
;	L2A_scan		type(msu_L2A_scn)	L2B scan information. 
;
; AUTHOR
;	Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;	THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;	THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;	AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;	AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;	SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;	THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT TO USERS.
;
; HISTORY
;	4/10/2018 Initial Version prepared for NCEI
;
; USAGE
;	call msu_l1b_to_l2a(L1b_Scan,L2a_scan,model_to_use)
;
;@*****
    subroutine msu_l1b_to_l2a(L1b_Scan,L2a_scan,model_to_use)


		use msu_roll_error
		use incidence_angle
		use msu_orbital_and_roll_corrections
		use msu_calibration

		type(msu_raw)			:: l1b_scan
		type(msu_L2A_scn)		:: l2a_scan
        	character(10),intent(IN),OPTIONAL :: model_to_use
        
        
		integer(4)				:: fov
		integer(4)				:: channel

		real(4),dimension(NUM_CHANNELS)	:: roll_error
		integer(4)					:: r_error
		integer(4)					:: inc_error
		integer(4)					:: diur_error
		
		call zero_msu_L2A_scan_long(L2a_scan)

		! transfer meta data

		l2a_scan%sat_num     = l1b_scan%sat_num
		l2a_scan%orbit_num   = l1b_scan%orbit_num
		l2a_scan%scan_number = l1b_scan%scan_number

		! transfer geolocation and date

		l2a_scan%height = l1b_scan%height		
		l2a_scan%height_corrected = l1b_scan%height_corrected
		
		do fov = 1,11
			L2A_scan%fov_longitude(fov) = L1B_scan%fov_longitude(fov)
			L2A_scan%fov_latitude(fov) = L1B_scan%fov_latitude(fov)
		enddo
		
		! transfer raw counts
		 do channel = 1,4
		    do fov = 1,14
		        l2a_scan%MSU_Counts(channel,fov) = l1b_scan%MSU_Counts(channel+3,fov)
		    enddo
		 enddo
		 
		l2a_Scan%date = l1b_scan%date

		! calculate counts corrected for non_linearity correction
		
		! look for zero scans...
		
		if ((abs(l1b_scan%date%rd_2000) .lt. 0.0000001) .or. (l1b_scan%sat_num .le. 0) .or. (l1b_scan%sat_num .ge. 10)) then
		    l2a_scan%scan_qual = ibset(l2a_scan%scan_qual,3)
		    return
		endif
		
		call calc_non_linearity_correction(L1B_scan,L2A_scan)

		! calculate resistances

		call calc_resistances(L1B_scan,L2A_scan)

		! calculate target temperatures

		call calc_target_temps(L2A_scan)

		! calculate raw Tbs (no diurnal or theta corrections

		call calc_raw_TBs(L2A_scan)

		! find estimated for roll error for each channel

		do channel = 1,4 
			roll_error(channel) = -msu_roll_error_angle(L2a_scan%sat_num,channel,L2A_scan%date,r_error)
		    l2a_scan%roll_err(channel) = roll_error(channel)
		enddo

		! find estimated incidence angle for each channel and field of view
		! incidence angles are channel dependent becuase the roll error estimate
		! is channel dependent

		do channel = 1,4
			do fov = 1,11
				L2A_scan%fov_incidence(channel,fov) = calc_EIA(	FOV,						&
																L2A_scan%height,			&
																L2A_scan%fov_latitude(fov),	&
																roll_error(channel),		&
																inc_error)
			enddo
		enddo
		
		! calculate incidence angle corrections

		call correct_to_nom_EIA_and_Nadir(L2A_scan,inc_error,model_to_use)

	end subroutine msu_L1b_to_L2a



;@***h* MLT_V4_RSS/function check_earth_locations
; NAME
;	function check_earth_locations
;
; PURPOSE
;	checks Earth locations to make sure they are different that zero
;
; DESCRIPTION
;	checks Earth locations to make sure they are different that zero
;	if either lat or lon is too close to 0.0000 for any FOV, then 1 is returned
;
; INPUTS
;	lats		real(4),dimension(NUM_FOVS)	array of latitudes
;	lons		real(4),dimension(NUM_FOVS)	array of longitudes
;
; OUTPUTS
;	return value	integer(4)		1 if any lon or lat too close to 0.00000, 0 otherwise 
;
; AUTHOR
;	Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;	THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;	THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;	AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;	AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;	SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;	THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT TO USERS.
;
; HISTORY
;	4/10/2018 Initial Version prepared for NCEI
;
; USAGE
;	locations_bad = check_earth_locations(lats,lons)
;
;@*****
	
	integer(4) function check_earth_locations(lats,lons)
	
	    real(4),dimension(NUM_FOVS)   :: lats
	    real(4),dimension(NUM_FOVS)   :: lons
	    
	    integer(4)                     :: fov
	    integer(4)                     :: num_eq_zero
	    
	    num_eq_zero = 0
	    check_earth_locations = 0
	    
	    do fov = 1,NUM_FOVS
	        if (abs(lats(fov)) .lt. 0.000001) num_eq_zero = num_eq_zero+1
	        if (abs(lons(fov)) .lt. 0.000001) num_eq_zero = num_eq_zero+1
	    enddo
	    
	    if (num_eq_zero .gt. 1) check_earth_locations = 1
	    
	    return
	end function check_earth_locations


;@***h* MLT_V4_RSS/eval_l2a_quality
; NAME
;	eval_l2a_quality
;
; PURPOSE
;	performs QC check on L2A data
;
; DESCRIPTION
;	performs QC check on L2A data
;	1. Transfers Qualty Info from L1B
;	2. Checks for Lat and Lon both zero
;	3. Checks for satellite hieght in bounds
;	4. Checks for cold counts in bounds
;	5. Checks for target temperature in bounds
;	6. Checks for brightness temperature in bounds

;
; INPUTS
;	L1B_scan		type(msu_raw)	L1B scan information
;	L2A_scan		type(msu_L2A_scn)	L2B scan information. 
;
; OUTPUTS
;	L2A_scan		type(msu_L2A_scn)	L2B scan information. 
;
; AUTHOR
;	Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;	THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;	THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;	AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;	AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;	SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;	THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT TO USERS.
;
; HISTORY
;	4/10/2018 Initial Version prepared for NCEI
;
; USAGE
;	locations_bad = check_earth_locations(lats,lons)
;
;@*****	
	integer(4) function eval_l2a_quality(L1b_scan,L2a_scan)
	
	    type(msu_L2A_scn)		:: l2a_scan
	    type(msu_raw)		:: l1b_scan
	    
	    integer(4)              :: num_eq_zero
	    integer(4)              :: num_fov_eq_zero
	    integer(4)              :: qc_status
	    
	    integer(4)              :: fov
	    integer(4)              :: chan
	    integer(4)              :: j
	    
	    integer(2),parameter    :: min_cold_counts = 100
	    integer(2),parameter    :: max_cold_counts = 1000
	    
	    
	    
	    qc_status = 0
	    
	    ! we start with quality flags from L1b
	    !
	    ! these are defined:
	    ! scan_qual_L1B =IBIT(0,1) + 2*IBIT(1,1) + 4*IBIT(6,1) + 8*IBIT(7,1) + 16*IBIT(7,2)
	        ! IBIT(0,1) = Earth Loc Delta
	        ! IBIT(1,1) = NO earth location
	        ! IBIT(6,1) = Data GAP
	        ! IBIT(7,1) = FATAL flag
	        ! IBIT(7,2) = Calibration Error for at least one channel
	        
	    ! transfer existing scan qual flags
	    
	    l2a_scan%scan_qual = l1b_scan%scan_quality
	        
	    ! for the quality flags we compute here, we use bit 9 and above  ie. 256 and above
	    
	    ! recheck earth location delta (some really large values got through the NOAA processing
	    
	    if (abs(l1b_Scan%earth_location_delta) .gt. 3.0) l2a_scan%scan_qual = ibset(l2a_scan%scan_qual,0)

	    
	    ! make sure lat and lon exist for all fovs
	    ! I allow one value of lat/lon to be zero, but if both are zero, data is flagged

	    num_eq_zero = 0
	    
	    do fov = 1,NUM_FOVS
	        num_fov_eq_zero = 0
	        if (abs(l2a_scan%fov_latitude(fov)) .lt. 0.000001) then 
	            num_eq_zero = num_eq_zero+1
	            num_fov_eq_zero = num_fov_eq_zero + 1
	        endif
	        if (abs(l2a_scan%fov_longitude(fov)) .lt. 0.000001) then
	            num_eq_zero = num_eq_zero+1
	            num_fov_eq_zero = num_fov_eq_zero + 1
	        endif
	        if (num_fov_eq_zero .eq. 2) then
	            do chan = 1,4
	                l2a_scan%fov_qual(chan,fov) = ibset(l2a_scan%fov_qual(chan,fov),1)
	            enddo
	        endif
	    enddo
	    
	    if (num_eq_zero .gt. 1) l2a_scan%scan_qual = ibset(l2a_scan%scan_qual,1)
	    
	    ! make sure corrected height exists and is reasonable
	    
	    if ((l2a_scan%height_corrected .lt. 600.) .or. (l2a_scan%height_corrected .gt. 1000.)) l2a_scan%scan_qual = ibset(l2a_scan%scan_qual,8)
	    
	    ! make sure that cold counts are in bounds
	    
	    do chan = 1,4
	        if ((l2a_scan%msu_counts(chan,SPACE) .lt. min_cold_counts) .or. (l2a_scan%msu_counts(chan,SPACE) .gt. max_cold_counts)) then
	            do fov = 1,11
	                l2a_scan%fov_qual(chan,fov) = ior(l2a_scan%fov_qual(chan,fov),128)
	            enddo
	        endif
	    enddo
	    
	    ! make sure Tbs are in bounds
	    
	    do chan = 1,4
	        do fov = 1,11
	            if ((l2a_scan%MSU_TBS_RAW(chan,fov) .lt. MIN_REASONABLE_TB(chan)) .or. (l2a_scan%MSU_TBS_RAW(chan,fov) .gt. MAX_REASONABLE_TB(chan))) then
	                l2a_scan%fov_qual(chan,fov) = ior(l2a_scan%fov_qual(chan,fov),8)
	            endif
	        enddo
	    enddo
	    
	    ! make sure T Target in bounds
	    
	    if ((L2A_scan%T%Target1_temp .lt. LOWER_TARGET_TEMP_LIMIT) .or. (L2A_scan%T%Target1_temp .gt. UPPER_TARGET_TEMP_LIMIT) .or. &
	        (abs(L2A_scan%T%Target1_temp_A-L2A_scan%T%Target1_temp_b) .gt. TARGET_TEMP_DIFF_LIMIT)) then
	        l2a_scan%scan_qual = ibset(l2a_scan%scan_qual,4)  ! at least one channel bad cal
	        l2a_scan%scan_qual = ibset(l2a_scan%scan_qual,16) ! channel 1 bad cal
	        l2a_scan%scan_qual = ibset(l2a_scan%scan_qual,17) ! channel 2 bad cal
	        do fov = 1,11
	             l2a_scan%fov_qual(1,fov) = ibset(l2a_scan%fov_qual(1,fov),7)
	             l2a_scan%fov_qual(2,fov) = ibset(l2a_scan%fov_qual(2,fov),7)
	        enddo
	    endif
	    
	    if ((L2A_scan%T%Target2_temp .lt. LOWER_TARGET_TEMP_LIMIT) .or. (L2A_scan%T%Target2_temp .gt. UPPER_TARGET_TEMP_LIMIT) .or. &
	          (abs(L2A_scan%T%Target2_temp_A-L2A_scan%T%Target2_temp_b) .gt. TARGET_TEMP_DIFF_LIMIT)) then
	        l2a_scan%scan_qual = ibset(l2a_scan%scan_qual,4)  ! at least one channel bad cal
	        l2a_scan%scan_qual = ibset(l2a_scan%scan_qual,18) ! channel 3 bad cal
	        l2a_scan%scan_qual = ibset(l2a_scan%scan_qual,19) ! channel 4 bad cal
	        do fov = 1,11
	             l2a_scan%fov_qual(3,fov) = ibset(l2a_scan%fov_qual(3,fov),7)
	             l2a_scan%fov_qual(4,fov) = ibset(l2a_scan%fov_qual(4,fov),7)
	        enddo
	    endif

	    eval_l2a_quality = l2a_scan%scan_qual
	    
	    
	    do j = 1,32
	        if (btest(l2a_scan%scan_qual,j-1))flag_set_array(j) = flag_set_array(j) +1
	    enddo 
	end function eval_l2a_quality 
    
    end module msu_l1b_to_l2a_monthly

    
    
    
    
        
        
        
    
    
    
    
    
    
    
    

    
    





