;@***h* MLT_V4_RSS/msu_l1b_to_L2a_monthly_driver
; NAME
;	msu_l1b_to_L2a_monthly_driver
;
; PURPOSE
;	top level driver script for converting MSU L1B to MSU L2A
;
; DESCRIPTION
;	top level driver script for converting MSU L1B to MSU L2A
;
; INPUTS
;	MSU L1B Monthly "R3" Files
;
; OUTPUTS
;	MSU L2A Monthly Files
;
; AUTHOR
;	Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;	THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;	THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;	AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;	AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;	SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;	THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT TO USERS.
;
; HISTORY
;	4/10/2018 Initial Version prepared for NCEI
;
; USAGE
;	top level program
;
;@*****

program msu_l1b_to_L2a_monthly_driver

    use nan_support
    use date_and_time
    use msu_l1b_to_l2a_monthly
        
    integer(4)           :: sat_num
    integer(4)           :: month
    integer(4)           :: year
    integer(4)           :: first_year
    integer(4)           :: last_year
    character(10)        :: model_to_use
    
    model_to_use = 'ncep'
   
    do sat_num = 1,9
	    select case (sat_num)
	        case(1) 
	            first_year = 1978
	            last_year = 1981
	        case(2)
	            first_year = 1979
	            last_year = 1986
	        case(3)
	            first_year = 1981
	            last_year = 1985
	        case(4)
	            first_year = 1983
	            last_year = 1985
	        case(5)
	            first_year = 1985
	            last_year = 1988	
	         case(6)
	            first_year = 1986
	            last_year = 1991	    
	         case(7)
	            first_year = 1988
	            last_year = 1999	
	         case(8)
	            first_year = 1991
	            last_year = 1998
	         case(9)
	            first_year = 1995  !1995
	            last_year =  2005  ! 2005
	        case default
	            print *,'Invalid Satellite Number'
	            stop
	    end select

        do year =first_year,last_year
            do month = 1,12
                call process_msu_L1B_monthly_to_L2A(sat_num,year,month,model_to_use)
            enddo
        enddo
   enddo  ! sat_num

end