pro make_msu_monthly_map_by_fov,satellite_name,year_to_read,month_to_read,channel,msu_l2a_hist_by_fov,error = error, tb_hist= tb_hist,model_String=model_String
;@***h* MLT_RSSv4/make_msu_monthly_map.pro
;
; NAME
;   make_msu_monthly_map.pro
;
; PURPOSE
;   reads a monthly MSUv4 L2A file, and reorganizes it into a gridded dataset
;   and writes a MSUv4 L2C "by fov" type file analogous to the AMSU by fov files
;
; DESCRIPTION
;   reads a monthly MSUv4 L2A file, and reorganizes it into a gridded dataset
;   and writes a MSUv4 L2C "by fov" type file analogous to the AMSU by fov files
;   
; INPUTS
;   satellite_name       ; string containing MSU satellite name
;   year_to_read         ; integer -- year to read
;   month_to_read        ; integer 1..12 -- month to read
;   channel               ; MSU channel number
;   
;   
; OUTPUTS
;   msu_l2a_hist_by_fov  ; gridded dataset
;   tb_hist              ; histogram of tbs -- for quality control
;   error                ; error flag.  0 means everything is OK, -1 Means a read error
;     
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE COPYRIGHT 2012 REMOTE SENSING SYSTEMS.  
;   THEY ARE PROVIDED FOR INFORMATIONAL AND ALGORITHM VERIFICATION PURPOSES ONLY 
;   AND MAY NOT BE USED IN WHOLE OR IN PART FOR ANY OTHER PURPOSE WITHOUT WRITTEN
;   PERMISSION FROM REMOTE SENSING SYSTEMS.  THEY ARE FURNISHED "AS IS." THE 
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
;   TO USERS.
;
; HISTORY
;   10/30/2013 Initial version written
;
; USAGE
;   make_msu_monthly_map,satellite_name,year_to_read,month_to_read,channel,msu_l2a_hist_by_fov,error = error, tb_hist= tb_hist
;
;@*****    

    level_string = 'R3'
    read_msu_L2Av4_monthly_file,satellite_name,year_to_read,month_to_read,msu_L2a,level_string = level_string,error,model_String=model_String
    if error ne 0 then return
    FOV_QUAL_MASK = 125
    num_scans = n_elements(msu_l2a)
    msu_l2a_hist_by_fov = fltarr(4,2,11,144,72)   ; (num,tb,tar,hgt) asc/dsc,fov,il0n,ilat)
    tb_hist = fltarr(11,300)
    chan = channel - 1
    iasc = 0
    for scan = 0,num_scans - 1 do begin
      if scan mod 10000 eq 0 then print,scan
      if msu_l2a[scan].scan_qual eq 0 then begin
        if msu_l2a[scan].height_corrected lt 700.0 then begin
          print,msu_l2a[scan].height,msu_l2a[scan].height_corrected
          print
        endif
        
        ; skip 2 bad days in March 1980 for NOAA-06 -- these days have bad geolocation, undetected until now
        
        if (satellite_name eq 'NOAA-06') then begin
          if (year_to_read eq 1980) then begin
            if (month_to_read eq 3) then begin
              if ((msu_l2a[scan].rd2000 gt -7244.0D0) and (msu_l2a[scan].rd2000 lt -7242.0D0)) then begin
                continue
              endif
            endif
            if (month_to_read eq 11) then begin
              if ((msu_l2a[scan].rd2000 gt -6977.0D0) and (msu_l2a[scan].rd2000 lt -6976.0D0)) then begin
                continue
              endif
            endif
          endif
        endif
        
        ; skip bad orbit in NOAA-14
        
        if (satellite_name eq 'NOAA-14') then begin
          if (year_to_read eq 1996) then begin
            if (month_to_read eq 4) then begin
              if ((msu_l2a[scan].rd2000 gt -1341.0D0) and (msu_l2a[scan].rd2000 lt -1340.85D0)) then begin
                continue
              endif
            endif
          endif
        endif
        
        iasc = 1
        if msu_l2a[scan].scan_number le 61 then iasc = 0  ; ascending
        if msu_l2a[scan].scan_number ge 181 then iasc = 0 ; ascending
        ; so 63 to 181 is descending
        ilon = floor(msu_l2a[scan].fov_longitude/2.5)
        ilat = floor((msu_l2a[scan].fov_latitude + 90.0)/2.5)
        
        if channel le 2 then begin
          target_temp = msu_l2a[scan].T.Target1_temp
        endif else begin
          target_temp = msu_l2a[scan].T.Target2_temp
        endelse
        ;msu_l2a_hist_by_fov = fltarr(4,2,11,144,72)   ; (num,tb,tar,hgt) asc/dsc,fov,il0n,ilat)

        for fov = 0,10 do begin
          if ((ilon[fov] ge 0) and (ilon[fov] le 143) and (ilat[fov] ge 0) and (ilat[fov] le 71)) then begin
             if (((125 and msu_l2a[scan].fov_qual[fov,chan]) eq 0) and (finite(msu_l2a[scan].msu_tbs_raw[fov,chan]) eq 1)) then begin  ; 2 and 128 are ok
                
                msu_l2a_hist_by_fov[0,iasc,fov,ilon[fov],ilat[fov]] = msu_l2a_hist_by_fov[0,iasc,fov,ilon[fov],ilat[fov]] + 1
                msu_l2a_hist_by_fov[1,iasc,fov,ilon[fov],ilat[fov]] = msu_l2a_hist_by_fov[1,iasc,fov,ilon[fov],ilat[fov]] + msu_l2a[scan].msu_tbs_raw[fov,chan]
                msu_l2a_hist_by_fov[2,iasc,fov,ilon[fov],ilat[fov]] = msu_l2a_hist_by_fov[2,iasc,fov,ilon[fov],ilat[fov]] + target_temp
                msu_l2a_hist_by_fov[3,iasc,fov,ilon[fov],ilat[fov]] = msu_l2a_hist_by_fov[3,iasc,fov,ilon[fov],ilat[fov]] + msu_l2a[scan].height_corrected

                if (msu_l2a[scan].msu_tbs_raw[fov,chan] lt 100.0) then begin
                    print,ilon[fov],ilat[fov],fov,msu_l2a[scan].msu_tbs_raw[fov,chan] 
                    print
                endif 
                itb = floor(msu_l2a[scan].msu_tbs_raw[fov,chan])
                if itb lt 0 then itb = 0
                if itb gt 299 then itb = 299
                tb_hist[fov,itb] = tb_hist[fov,itb] + 1
             endif
          endif         
        endfor  ; fov
      endif     ; if msu_l2a[scan].scan_qual eq 0
    endfor      ; scan
end
