;@***h* MLT_V4_RSS/month_map_TLT_driver.pro
; NAME
; month_map_TLT_driver.pro
;
; PURPOSE
; top level program to construct monthly MSU V4 TLT radiance maps by field of view.
;
; DESCRIPTION
; top level program to construct monthly MSU V4 TLT radiance maps by field of view.
; this is part of the msu V4 routine processing.
;
; INPUTS
; None.
;
; OUTPUTS
; The program creates monthly radiance maps in flat binary format.
; e.g. ...\AMSU-A_L2C\Monthly_Maps_V4\AMSU_Channel_05\TLT_maps\NOAA-19\tb_ccm3\y2009_m07_FOV_Hist_144_72_V4_01.dat
; separate sets of maps exist for each model adjustment.
;
; AUTHOR
; Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
; THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
; THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
; AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
; AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
; SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
; THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT TO USERS.
;
; HISTORY
; 5/10/2018 Initial Version prepared for NCEI
;
; USAGE
; .r month_map_TLT_driver.pro
;
;@*****
begin_year_list = [1978,1979,1981,1983,1985,1986,1988,1991,1995]
end_year_list   = [1982,1986,1985,1986,1988,1991,1998,1998,2005]
for tlt_version = 0,1 do begin   ; 1 = perform EIA correction
  for satnum = 1,9 do begin 
    satellite_name = sat_name(satnum,/fill)
    begin_year     = 1L*begin_year_list[satnum-1]
    end_year       = 1L*end_year_list[satnum-1]  
    for year = begin_year,end_year do begin
      for month = 1L,12L do begin
          make_msu_monthly_map_V4_TLT,satellite_name,year,month,msu_l2a_hist_TLT,error = error, tb_hist= tb_hist,model_String='merra',TLT_version = TLT_version
          if error eq 0 then begin
            outfile = string(satellite_name,year,month,tlt_version,format='("M:\MSU_AMSU_Data\MSU_L2C\Monthly_Maps_v4\MSU_Channel_02\tlt_maps\",a,"\tb_no_adj\y",i4.4,"_m",i2.2,"_tlt_hist_144_72_v4_",i2.2,".dat")')
            print,outfile
            ok = check_path(outfile,/create)
            close,3
            openw,3,outfile
            writeu,3,month,year,msu_l2a_hist_tlt,tb_hist
            close,3
          endif
      endfor
    endfor
  endfor
endfor

end