;@***h* MLT_V4_RSS/calc_adjustments_msu_fov_main.pro
; NAME
;   MLT_V4_RSS/calc_adjustments_msu_fov_main.pro
;
; PURPOSE
;   top level program that calculates angle and diurnal adjustment for MSU
;
; DESCRIPTION
;   top level program that calculates angle and diurnal adjustment for MSU
;   
; INPUTS
;   none
; OUTPUTS
;   writes diurnal and angle adjustment gridded monthly files
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   4/10/2018 Initial Version prepared for NCDC
;
; USAGE
;   .r calc_adjustments_msu_fov_main
;
;@*****

load_AMSU_file_locations,verbose=1

; define commom blocks
; EIA common block -- contains info need for the angle adjustments

common eia, eia__adj_arr, eia__channel_loaded,eia__model_loaded,eia__lat_map, $
       eia__cross_track_offsets,eia__cross_track_sat_loaded,eia__cross_track_channel_loaded, $
       AMSU_VIEW_ANGLES,AMSU_NOM_EIAS,MSU_VIEW_ANGLES,MSU_NOM_EIAS

eia__channel_loaded = -1
eia__cross_track_sat_loaded = -1
eia__cross_track_channel_loaded = -1

eia__model_loaded = 'none'

MSU_VIEW_ANGLES = [0.0, 9.47,18.94,28.41,37.88,47.35]
MSU_NOM_EIAS    = [0.0,10.71,21.51,32.51,43.91,56.19]

                        
; END EIA common block

; Diurnal common block
common diurnal, diur__adj_arr, diur__channel_loaded,diur__model_loaded,diur__lat_time_map
  diur__channel_loaded = -1
  diur__model_loaded  = 'none'
; END Diurnal Common Block
                    
for channel = 2,4 do begin
  channel_str = string(channel,format = '("MSU",i2.2)')
  fov_wts = fltarr(11)
  fov_wts[3:7] = 1.0
  
  node_wts = [1.0,1.0]
  adj_flag = 7
  
  num_sats = n_elements(sats_to_use)
  eia_model_list = ['NCEP','MERRA']
  eia_model_list = ['MERRA']  ;;temporary
  diur_model_list = ['CCM3','MERRA','HADGEM','CMAM']
  
  eia_model = 'MERRA'
  foreach diur_model,diur_model_list do begin
      ;if channel eq 2 then calc_and_save_all_MSU_diurnal_TLT,eia_model = eia_model,diur_model=diur_model,tb_arr_adj,tar_arr=tar_arr,num_arr=num_arr,sats_to_use = sats_to_use
      calc_and_save_all_MSU_diurnal_from_FOV,channel,fov_wts,node_wts,adj_flag,eia_model = eia_model,diur_model=diur_model,tb_arr_adj,tar_arr=tar_arr,num_arr=num_arr,sats_to_use = sats_to_use
  endforeach
  
  foreach eia_model,eia_model_list do begin
    diur_model = 'CCM3'
    ;if channel eq 2 then calc_and_save_MSU_angle_adjustments_TLT_V4,channel,eia_model = eia_model,sats_to_use = sats_to_use
    calc_and_save_all_MSU_adjustments_from_FOV,channel,fov_wts,node_wts,adj_flag,eia_model = eia_model, $
                                               diur_model=diur_model,tb_arr_adj,tar_arr=tar_arr,num_arr=num_arr,sats_to_use = sats_to_use
  endforeach
endfor

end
