;@***h* MLT_V4_RSS/fill_msu_measurement_times.pro
; NAME
;   MLT_V4_RSS/fill_msu_measurement_times.pro
;
; PURPOSE
;   fills any maps of MSU local measurement time with the zonal mean for that zone
;
; DESCRIPTION
;   fills any maps of MSU local measurement time with the zonal mean for that zone
;
; INPUTS
;  measurement_times      array of reals [144,72,11,2]:  local measurement time
;
; OUTPUTS
;  measurement_times      array of reals [144,72,11,2]:  local measurement time
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   4/10/2018 Initial Version prepared for NCDC
;
; USAGE
;   fill_msu_measurement_times,measurement_times
;
;@*****

pro fill_msu_measurement_times,measurement_times

  for fov = 0,10 do begin
    for iasc = 0,1 do begin
      map = measurement_times[*,*,fov,iasc]
      zm = compute_zonal_average_from_144_72_map(map)
      for ilat = 0,71 do begin
        if finite(zm[ilat]) eq 1 then begin
          zone = map[*,ilat]
          bad = where(finite(zone) eq 0,bad_ct)
          if bad_ct gt 0 then zone[bad] = zm[ilat]
          map[*,ilat] = zone
        endif
      endfor
      measurement_times[*,*,fov,iasc] = map
    endfor
 endfor
 
end