;@***h* MLT_V4_RSS/get_msu_measurement_times.pro
; NAME
;   MLT_V4_RSS/get_msu_measurement_times.pro
;
; PURPOSE
;   reads maps of MSU local measurement time for a given satellite, year and month
;
; DESCRIPTION
;   reads maps of MSU local measurement time for a given satellite, year and month
;   there are difference maps for each FOV because of the difference in local time across
;   each swath
;
; INPUTS
;   satnum              integer: satellite number (1..9)
;   year                integer: year to process
;   month               integer: month of year to process
;
; OUTPUTS
;  local_time_maps      array of reals [144,72,11,2]:  local measurement time
;  error                integer error flag.  A value of zero means no errors.
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   4/10/2018 Initial Version prepared for NCDC
;
; USAGE
;   get_msu_measurement_times,satnum,year,month,local_time_maps,error = error
;
;@*****




pro get_msu_measurement_times,satnum,year,month,local_time_maps,error = error   ; measurement times is 144 x 72 x 15 array of local times

  common diurnal
  
  satellite_name = sat_name(satnum,/fill)
  channel = diur__channel_loaded
  save_file = 'M:\MSU_AMSU_Data\MSU_L2Cv2\monthly_maps\' + satellite_name + '\'+ $
    string(channel,year,month,format = '("msu_tb_hist_'+ satellite_name + '_channel_",i2.2,"_y",i4.4,"_m",i2.2,".loc_time.R3.sav")')
  info = FILE_INFO(save_file)
  if info.exists eq 0 then begin
    error = -1
    local_time_maps = replicate(!values.f_nan,144, 72, 11, 2)
    return
  endif
  restore,save_file
  error = 0
end