;@***h* MLT_V4_RSS/get_nth_value.pro
; NAME
;   MLT_V4_RSS/get_nth_value.pro
;
; PURPOSE
;   allows rapid indexing of a 3d array in the third dimension by values in a 2-d array
;
; DESCRIPTION
;   allows rapid indexing of a 3d array in the third dimension by values in a 2-d array
;
; INPUTS
;  array_3d       any 3-d array
;  array_2d       integer: 2-d array of indices
;
; OUTPUTS
;  return value:   2d array of values from the 3d array sampled at the indices supplied in the call
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   4/10/2018 Initial Version prepared for NCDC
;
; USAGE
;    x = get_nth_value(array_3d,array_2d)
;
;@*****
;
function get_nth_value,array_3d,array_2d

; This routine allows rapid indexing of a 3d array in the third dimension by values
; in a 2-d array.  
;
; inputs:
;   array_3d      any 3-d array with dimensions d1,d2,d3
;   array_2d      array of integers with dimensions d1,d2
;                 The values should range from 0 to d3-1
;
; return value
;   a 2-d array with dimensions d1,d2
;   result[i,j] = array_3d[i,j,array_2d[i,j]]

sz1 = size(array_3d,/dimensions)
sz2 = size(array_2d,/dimensions)

if ((sz1[0] ne sz2[0]) or (sz1[1] ne sz2[1])) then begin
  print,'Size error in get_nth_value'
  return,!values.f_nan
endif
array2d = floor(array_2d)
if ((min(array_2d) lt 0) or (max(array2d) gt sz1[2]-1)) then begin
  print,'Range error in get_nth_value
  return,!values.f_nan
endif
 
step = sz1[0]*sz1[1]
index = findgen(step) + reform(array_2d,sz2[0]*sz2[1])*step
return,reform(array_3d[index],sz2[0],sz2[1])

end