;@***h* MLT_V4_RSS/read_msu_diurnal_adj_arr_v4.pro
; NAME
;   MLT_V4_RSS/read_msu_diurnal_adj_arr_v4.pro
;
; PURPOSE
;   reads msu diurnal adjustment arrays
;
; DESCRIPTION
;   reads msu diurnal adjustment arrays
;
; INPUTS
;   channel   integer, MSU channel number
;   model     string containing name of diurnal adjustment model ('CCM3','MERRA','HADGEM')
;   rebin     set to 1 to rebin NCEP results to RSS standard 2.5 degree grid (usually set)
;
; OUTPUTS
;   diur_tbs  array of reals [12,6,144,72,24] of diurnal adjustment parameters.
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   4/10/2018 Initial Version prepared for NCDC
;
; USAGE
;   read_msu_diurnal_adj_arr_v4,2,'CCM3',diur_Tbs,err
;
;@*****



pro read_msu_diurnal_adj_arr_v4,channel,model,diur_tbs,err
  err = -1
  
  diur_file = string(!MSU_ADJUSTMENT_PATH,model,channel,model, $
    format = '(a,"MSU_Diurnal\",a,"_Diurnal_Climatology\mn_diur_cycles_chan_",i1.1,"_",a,"_144x72.dat")')
  
  diur_tbs = fltarr(12,6,144,72,24)
  close,3
  openr,3,diur_file
  mat = fltarr(144,72)
  for fov = 0,5 do begin
    for month = 0,11 do begin
      for hour = 0, 23 do begin       
        ; 5-fov reverses order so that fov = 1 is the nader position 
        readu,3, mat
        diur_tbs[month,5-fov,*,*,hour] = mat
      endfor
    endfor
  endfor 
  err = 0
  end