;@***h* MLT_V4_RSS/read_msu_ncep_nadir_adj_v4.pro
; NAME
;   MLT_V4_RSS/read_msu_ncep_nadir_adj_v4.pro
;
; PURPOSE
;   reads msu NCEP angle adjustment arrays
;
; DESCRIPTION
;   reads msu NCEP angle adjustment arrays
;
; INPUTS
;   channel   integer, MSU channel number
;   month     integer, 1..12, month number
;   rebin     set to 1 to rebin NCEP results to RSS standard 2.5 degree grid (usually set)
;   
; OUTPUTS
;   adj_array array of reals (3,6,144,72) of angle adjustment parameters.
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   4/10/2018 Initial Version prepared for NCDC
;
; USAGE
;   read_msu_ncep_nadir_adj_v4,2,10,adj_array
;
;@*****

pro read_msu_ncep_nadir_adj_v4,channel,month,adj_array,rebin=rebin
  file = string(channel,month,format = '("M:\MSU_AMSU_Data\MSU_Adjustments\NCEP_modelled_tbs\channel_MSU",i1,"\ncep_msu_tbs_LTM_",i2.2,".dat")')
  close,3
  openr,3,file
  adj_array = fltarr(3,6,144,73,2)
  readu,3,adj_array
  close,3
  
  if keyword_Set(rebin) then begin
    temp = adj_array
    adj_array = fltarr(3,6,144,72,2)
    for type = 0,2 do begin
      for fov = 0,5 do begin
        for surf = 0,1 do begin
          adj_array[type,fov,*,*,surf] = rebin_144_73_to_144_72(temp[type,fov,*,*,surf])
        endfor
      endfor
    endfor
  endif
end