;@***h* MLT_V4_RSS/write_msu_nadir_adjustment_fov.pro
; NAME
;   MLT_V4_RSS/write_msu_nadir_adjustment_fov.pro
;
; PURPOSE
;   writes MSU nadir adjustment maps
;
; DESCRIPTION
;   writes MSU nadir adjustment maps
;
; INPUTS
;   satnum                  integer: satellite number (1..9)
;   channel                 integer:  MSU channel number
;   year                    integer: year to process
;   month                   integer: month to process
;  nadir_model            string:  name of diurnla model used
;  nadir_adjustment       array of reals [2,11,144,72]: nadir adjustment maps to save
;
; OUTPUTS
;  none
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   4/10/2018 Initial Version prepared for NCDC
;
; USAGE
;    write_msu_nadir_adjustment_fov,satnum,channel,year,month,nadir_model,nadir_adjustment,error
;
;@*****
pro write_msu_nadir_adjustment_fov,satnum,channel,year,month,eia_model,nadir_adjustment,error

  if ((satnum lt 1) or (satnum gt 9)) then begin
    print,'Satnum '+string(satnum)+' is not an MSU instrument'
    err = -1
    return
  endif
  name = sat_name(satnum,/fill)
  ; example path: U:\AMSU-A_L2C\Monthly_Maps\AMSU_Channel_10\fov_maps\noaa-15\y1998_m08_fov_hist_144_72_v3_02.dat'
  path = string(channel,name,format='("M:\MSU_AMSU_data\MSU_L2C\Monthly_Maps_V4\MSU_Channel_",i2.2,"\fov_maps\",a,"\nadir_adjustment\")')
  info = file_info(path)
  if info.exists eq 0 then begin
    file_mkdir,path
  endif
  file = path + string(year,month,eia_model,format = '("y",i4.4,"_m",i2.2,"_fov_hist_144_72_v4_01.",a,".dat")')
  close,3
  openw,3,file
  writeu,3,month,year,channel
  pad = '                '
  len = strlen(eia_model)
  eia_model_pad = eia_model + strmid(pad,0,16-len)
  writeu,3,eia_model_pad
  writeu,3,nadir_adjustment
  close,3
end
