pro apply_offsets_to_grpt_maps_AMSU_v4_land_ocean_sep,tb_arr_adj,offsets


;@***h* MLT_V4_RSS/apply_offsets_to_grpt_maps_AMSU_v4_land_ocean_sep
; NAME
;   apply_offsets_to_grpt_maps_AMSU_v4_land_ocean_sep
;
; PURPOSE
;   applies offset values to antenna temperature data
;
; DESCRIPTION
;   applies offset values to antenna temperature data.  Different offsets are applied for each satellite, latitude and surface type 
;   (land or sea)
;   
; INPUTS
;   tb_arr_adj            fltarr array (144 x 72 x num_months x num_sats) of adjusted antenna temperatures
;   offsets               fltarr array (72 x num_sats x 2) of offset values
;   
; OUTPUTS
;   tb_arr_adj            fltarr array (144 x 72 x num_months x num_sats) of adjusted antenna temperatures
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   1/10/2018 Initial Version prepared for NCDC
;
; USAGE
;   apply_offsets_to_grpt_maps_AMSU_v4_land_ocean_sep,tb_arr_adj3,offsets_adj_sm
;
;@*****

   
	; compute the offsets separately for each latitude
	sz = size(tb_arr_adj,/dimensions)

	num_lons 	= sz[0]
	num_lats 	= sz[1]
	num_months 	= sz[2]
	num_sats 	= sz[3]
	
	read_land_fraction_144_72,lf
  
  offset_maps = replicate(!values.f_nan,num_lons,num_lats,num_sats)
  for satnum = 0,num_sats-1 do begin
    land_offset_map = fltarr(num_lons,num_lats)
    ocean_offset_map = fltarr(num_lons,num_lats)
    for ilon = 0,num_lons - 1 do begin
      ocean_offset_map[ilon,*] = offsets[*,satnum,0]
      land_offset_map[ilon,*] = offsets[*,satnum,1]
    endfor
    offset_map_combined = lf*land_offset_map + (1.0 - lf)*ocean_offset_map
    offset_maps[*,*,satnum] = offset_map_combined
  endfor
    
	for satnum = 0,num_sats-1 do begin
	  for month = 0,num_months-1 do begin
			tb_arr_adj[*,*,month,satnum] = tb_arr_adj[*,*,month,satnum]-offset_maps[*,*,satnum]
		endfor
	endfor
	
end