;@***h* MLT_RSSv4/apply_TF_to_grpt_maps_v4.pro
;
; NAME
;   apply_TF_to_grpt_maps_v4.pro
;
; PURPOSE
;   applies target factors to MSU radiance data
;
; DESCRIPTION
;   applies target factors to MSU radiance data
;
; INPUTS
;   tb_arr            array (144,72,336,9( reals containing monthly radiance maps for each of 9 satellites
;   tar_arr           array (144,72,336,9( reals containing monthly target temperature maps for each of 9 satellites
;   channel           string containing the channel name ('TLT','TMT','TTS','TLS')
;   months_to_use     array of (336,9) integers.  Set value to one to use that satellite-month, set to -1 to excluded that satellite-month
;   target_factor           array of 9 target factors
;   target_means            array of 9 target means
;   surf_str         string decribing what surface type to use.
;
; OUTPUTS
;   tb_arr_adj           array of (336,9) reals.  Radiances adjusted for target factor affect.
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE COPYRIGHT 2012 REMOTE SENSING SYSTEMS.
;   THEY ARE PROVIDED FOR INFORMATIONAL AND ALGORITHM VERIFICATION PURPOSES ONLY
;   AND MAY NOT BE USED IN WHOLE OR IN PART FOR ANY OTHER PURPOSE WITHOUT WRITTEN
;   PERMISSION FROM REMOTE SENSING SYSTEMS.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   5/15/2018 Initial version submitted to NCEI
;
; USAGE
;   apply_TF_to_grpt_maps_v4,tb_arr,tar_arr,channel,target_factors,target_means,months_to_use,tb_arr_adj
;
;@*****


pro apply_TF_to_grpt_maps_v4,tb_arr,tar_arr,channel,target_factors,target_means,months_to_use,tb_arr_adj

	sz = size(tb_arr,/dimensions)
	num_months = sz[2]
	num_sats = sz[3]

	;trop_num_arr[63,1] = temp

	tb_arr_adj = tb_arr/0.0
	for month = 0,num_months-1 do begin
		for satnum = 0,num_sats-1 do begin
			if months_to_use[month,satnum] lt 0.5 then continue
			tb_arr_adj[*,*,month,satnum] = tb_arr[*,*,month,satnum] - target_factors[satnum]*(tar_arr[*,*,month,satnum]-target_means[satnum])
		endfor
	endfor
end
