;@***h* MLT_RSS/calc_tb_clim_Arr.pro
;
; NAME
;   calc_tb_clim_Arr.pro
;
; PURPOSE
;   calculates radiance climatology for each month for use calculating tb factors
;
; DESCRIPTION
;   calculates radiance climatology for each month for use calculating tb factors
;   
; INPUTS
;   tb_arr            array (144,72,336,9( reals containing monthly radiance maps for each of 9 satellites
;   months_to_use     array of (336,9) integers.  Set value to one to use that satellite-month, set to -1 to excluded that satellite-month
;   
; OUTPUTS
;   tb_clim_arr       array of reals (144,72,12) float32 array of radiance climatology
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE COPYRIGHT 2012 REMOTE SENSING SYSTEMS.
;   THEY ARE PROVIDED FOR INFORMATIONAL AND ALGORITHM VERIFICATION PURPOSES ONLY
;   AND MAY NOT BE USED IN WHOLE OR IN PART FOR ANY OTHER PURPOSE WITHOUT WRITTEN
;   PERMISSION FROM REMOTE SENSING SYSTEMS.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   5/21/2018 Initial Version prepared for NCDC
;
; USAGE
;   calc_tb_clim_Arr,tb_arr,months_to_use,tb_clim_arr
;
;@*****


pro calc_tb_clim_Arr,tb_arr,months_to_use,tb_clim_arr

  tb_clim_arr = fltarr(144,72,12)
  tb_clim_ok  = fltarr(144,72,12)
  
  
  for imonth = 0,335 do begin
    for satnum = 0,8 do begin
      if months_to_use[imonth,satnum] gt 0.5 then begin
        imonth2 = imonth mod 12
        map = tb_arr[*,*,imonth,satnum]
        ok = where(finite(map) eq 1,ct,complement=not_ok)
        ok_map = fltarr(144,72)
        ok_map[ok] = 1
        map[not_ok] = 0.0
        tb_clim_arr[*,*,imonth2] = tb_clim_arr[*,*,imonth2] + map
        tb_clim_ok[*,*,imonth2] = tb_clim_ok[*,*,imonth2] + ok_map
      endif
    endfor
  endfor
  
  tb_clim_arr = tb_clim_arr/tb_clim_ok
end
