pro initialize_MSU_System_Variables_V4

  ;@***h* MLT_RSS/initialize_MSU_System_Variables_V4.pro
  ;
  ; NAME
  ;   initialize_MSU_System_Variables_V4.pro
  ;
  ; PURPOSE
  ;   sets a number of IDL system variables for the MSU data merge.
  ;
  ; DESCRIPTION
  ;   sets a number of IDL system variables for the MSU data merge.
  ; INPUTS
  ;   offsets         none
  ; OUTPUTS
  ;   offsets_smooth  none
  ; AUTHOR
  ;   Carl Mears, Remote Sensing Systems
  ;
  ; COPYRIGHT
  ;   THIS SOFTWARE AND ITS DOCUMENTATION ARE COPYRIGHT 2012 REMOTE SENSING SYSTEMS.
  ;   THEY ARE PROVIDED FOR INFORMATIONAL AND ALGORITHM VERIFICATION PURPOSES ONLY
  ;   AND MAY NOT BE USED IN WHOLE OR IN PART FOR ANY OTHER PURPOSE WITHOUT WRITTEN
  ;   PERMISSION FROM REMOTE SENSING SYSTEMS.  THEY ARE FURNISHED "AS IS." THE
  ;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
  ;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
  ;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
  ;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
  ;   TO USERS.
  ;
  ; HISTORY
  ;   3/29/2012 Initial Version prepared for NCDC
  ;
  ; USAGE
  ;   initialize_MSU_System_Variables_V4
  ;
  ;@*****

; basic constants
	defsysv,'!year_range',[1979,2011]
	defsysv,'!num_pentads',2100
	defsysv,'!num_days' ,!num_pentads * 5
	defsysv,'!num_MSUs' ,9
	defsysv,'!num_AMSUs',6
	defsysv,'!num_sats',!num_MSUs + !num_AMSUs
	defsysv,'!num_months', 12*(1+!year_Range[1]-1978)
	defsysv,'!num_years',!num_months/12

	defsysv,'!Num_GrPt_Lats',72
	defsysv,'!Num_GrPt_Lons',144

	defsysv,'!Num_Nodes',2
	defsysv,'!Log_lun',9

; Paths imported from Fortran

	load_AMSU_file_locations
	!AMSU_L2C_Path = 'M:\MSU_AMSU_Data\AMSU-A_L2C\'
	;	fortran_file = '\\dell-p1700d\e\AMSU_processing\fortran_dev\Source\AMSU_File_Locations.f90'

; Auxiliary File locations:

    ; measurement times
  ; I think these are all no longer used....
	defsysv,'!Daily_LECT_file','\\dell-p1700d\e\AMSU_processing\module_data\amsu_utilities\measurement_times\Local_Equator_Crossing_Times_Daily.dat'
	defsysv,'!Pentad_LECT_file','\\dell-p1700d\e\AMSU_processing\module_data\amsu_utilities\measurement_times\Local_Equator_Crossing_Times_Pentad.dat'
	defsysv,'!Relative_Meas_Time_file','\\dell-p1700d\e\AMSU_processing\module_data\amsu_utilities\measurement_times\x_time_arrays.sav'

	; zonal target temperatures
	; I think these are all no longer used....
	defsysv,'!MSU_zonal_target_temp_path','\\dell-p1700d\e\AMSU_Processing\Module_Data\MSU_Utilities\MSU_Target_Temps\'
	defsysv,'!AMSU_zonal_target_temp_path','\\dell-p1700d\e\AMSU_Processing\Module_Data\AMSU_Utilities\AMSU_Target_Temps\'

; Result paths
; I think these are all no longer used....
	defsysv,'!global_merge_results_path','\\dell-p866a\m\global_merge_results\'
	defsysv,'!grpt_merge_results_path',  '\\dell-p866a\m\grpt_merge_results_operational\'
	defsysv,'!grpt_merge_results_path_1700d','\\dell-p1700d\f\MSU_Level_1B_Gridded\'

; Format strings for constructing L2B file names
; I think these are all no longer used....
;
;	defsysv,'!format_Str_Tb','("'+!AMSU_L2C_path+'zonal_pentads\MSU_channel_",i1,"\L1A_",i2.2,"_chan_",i1,"_Zonal_Pentad_36_",a,"_raw_mo_1995_direct.dat")'
;	defsysv,'!msu_format_Str_Tb','("'+!AMSU_L2C_path+'zonal_pentads\MSU_channel_",i1,"\L1A_",i2.2,"_chan_",i1,"_Zonal_Pentad_36_",a,"_raw_mo_1995_direct.dat")'
;	defsysv,'!format_Str_Tb_v02_1','("'+!AMSU_L2C_path+'zonal_pentads_v02_1\MSU_channel_",i1,"\L1A_",i2.2,"_chan_",i1,"_Zonal_Pentad_36_",a,"_raw_mo_1995_direct.dat")'
;	defsysv,'!format_Str_inc','("'+!AMSU_L2C_path+'zonal_pentads\MSU_channel_",i1,"\L1A_",i2.2,"_chan_",i1,"_Zonal_Pentad_36_",a,"_inc_direct.dat")'
;	defsysv,'!format_Str_limb','("'+!AMSU_L2C_path+'zonal_pentads\MSU_channel_",i1,"\L1A_",i2.2,"_chan_",i1,"_Zonal_Pentad_36_",a,"_limb_direct.dat")'
;	defsysv,'!format_Str_diur','("'+!AMSU_L2C_path+'zonal_pentads\MSU_channel_",i1,"\L1A_",i2.2,"_chan_",i1,"_Zonal_Pentad_36_",a,"_diurnal_direct.dat")'
;	defsysv,'!format_Str_climate','("'+!AMSU_L2C_path+'zonal_pentads\MSU_channel_",i1,"\L1A_",i2.2,"_chan_",i1,"_Zonal_Pentad_36_",a,"_clim_direct.dat")'
;	defsysv,'!format_str_target','("'+!AMSU_L2C_path+'zonal_pentads\MSU_target\L1A_",i2.2,"_target_",i1,"_Zonal_Pentad_36_",a,"_direct.dat")'
;	defsysv,'!format_str_target_v4','("'+!AMSU_L2C_path+'zonal_pentads_v4\MSU_target\L1A_",i2.2,"_target_",i1,"_Zonal_Pentad_36_",a,"_direct.dat")'
;	defsysv,'!format_str_target_v02_1','("'+!AMSU_L2C_path+'zonal_pentads_v02_1\MSU_target\L1A_",i2.2,"_target_",i1,"_Zonal_Pentad_36_",a,"_direct.dat")'
;	defsysv,'!format_Str_zonal_monthly_Tb',    '("'+!AMSU_L2C_path+'zonal_months\AMSU_channel_",i2.2,"\AMSU_",i2.2,"_chan_",i1,"_Zonal_Month_36_mo_1995.dat")'
;	defsysv,'!format_Str_zonal_monthly_limb',  '("'+!AMSU_L2C_path+'zonal_months\AMSU_channel_",i2.2,"\AMSU_",i2.2,"_chan_",i1,"_Zonal_Month_36_limb.dat")'
;	defsysv,'!format_Str_zonal_monthly_diur',  '("'+!AMSU_L2C_path+'zonal_months\AMSU_channel_",i2.2,"\AMSU_",i2.2,"_chan_",i1,"_Zonal_Month_36_diurnal.dat")'
;	defsysv,'!format_str_zonal_monthly_target','("'+!AMSU_L2C_path+'zonal_months\AMSU_target\AMSU_",i2.2,"_channel_",i1,"_Target_Zonal_Month_36.dat")'
;	defsysv,'!format_Str_zonal_monthly_Tb_v3',    '("'+!AMSU_L2C_path+'zonal_months\AMSU_channel_",i2.2,"\AMSU_",i2.2,"_chan_",i2.2,"_Zonal_Month_36_v3_02.",a,".dat")'
;	defsysv,'!format_Str_zonal_monthly_inc_v3',  '("'+!AMSU_L2C_path+'zonal_months\AMSU_channel_",i2.2,"\AMSU_",i2.2,"_chan_",i2.2,"_Zonal_Month_36_inc_v3_02.",a,".dat")'
;	defsysv,'!format_Str_zonal_monthly_limb_v3',  '("'+!AMSU_L2C_path+'zonal_months\AMSU_channel_",i2.2,"\AMSU_",i2.2,"_chan_",i2.2,"_Zonal_Month_36_nadir_v3_02.",a,".dat")'
;	defsysv,'!format_Str_zonal_monthly_diur_v3',  '("'+!AMSU_L2C_path+'zonal_months\AMSU_channel_",i2.2,"\AMSU_",i2.2,"_chan_",i2.2,"_Zonal_Month_36_diurnal_v3_02.",a,".dat")'
;	defsysv,'!format_str_zonal_monthly_target_v3','("'+!AMSU_L2C_path+'zonal_months\AMSU_target\AMSU_",i2.2,"_channel_",i2.2,"_Target_Zonal_Month_36_v3_02.dat")'
;	defsysv,'!format_Str_zonal_monthly_Tb_v3_02',    '("'+!AMSU_L2C_path+'zonal_months\AMSU_channel_",i2.2,"\AMSU_",i2.2,"_chan_",i1,"_Zonal_Month_36_v3_02.dat")'
;	defsysv,'!format_Str_zonal_monthly_inc_v3_02',  '("'+!AMSU_L2C_path+'zonal_months\AMSU_channel_",i2.2,"\AMSU_",i2.2,"_chan_",i1,"_Zonal_Month_36_inc_v3_02.dat")'
;	defsysv,'!format_Str_zonal_monthly_limb_v3_02',  '("'+!AMSU_L2C_path+'zonal_months\AMSU_channel_",i2.2,"\AMSU_",i2.2,"_chan_",i1,"_Zonal_Month_36_nadir_v3_02.dat")'
;	defsysv,'!format_Str_zonal_monthly_diur_v3_02',  '("'+!AMSU_L2C_path+'zonal_months\AMSU_channel_",i2.2,"\AMSU_",i2.2,"_chan_",i1,"_Zonal_Month_36_diurnal_v3_02.dat")'
;	defsysv,'!format_str_zonal_monthly_target_v3_02','("'+!AMSU_L2C_path+'zonal_months\AMSU_target\AMSU_",i2.2,"_channel_",i2.2,"_Target_Zonal_Month_36_v3_02.dat")'
;	defsysv,'!format_Str_msu_zonal_monthly_Tb',    '("'+!AMSU_L2C_path+'zonal_months\MSU_channel_",i1,"\L1A_",i2.2,"_chan_",i1,"_Zonal_Month.dat")'
;	defsysv,'!format_Str_msu_zonal_monthly_inc',  '("'+!AMSU_L2C_path+'zonal_months\msu_channel_",i1,"\L1A_",i2.2,"_chan_",i1,"_Zonal_Month_inc.dat")'
;	defsysv,'!format_Str_msu_zonal_monthly_limb',  '("'+!AMSU_L2C_path+'zonal_months\msu_channel_",i1,"\L1A_",i2.2,"_chan_",i1,"_Zonal_Month_limb.dat")'
;	defsysv,'!format_Str_msu_zonal_monthly_diur',  '("'+!AMSU_L2C_path+'zonal_months\msu_channel_",i1,"\L1A_",i2.2,"_chan_",i1,"_Zonal_Month_diurnal.dat")'
;	defsysv,'!format_str_msu_zonal_monthly_target','("'+!AMSU_L2C_path+'zonal_months\msu_target\L1A_",i2.2,"_Target_",i1,"_Zonal_Month.dat")'

	host_set
end