;@***h* MLT_RSSv4/load_AMSU_file_locations.pro
;
; NAME
;   load_AMSU_file_locations.pro
;
; PURPOSE
;   reads and parses a fortran 90 source file to obtain locations for various MSU datases. 
;
; DESCRIPTION
;   reads and parses a fortran 90 source file to obtain locations for various MSU datases. 
;
; INPUTS
;   verbose     flag: set to one for additions reporting            
;
; OUTPUTS
;   none
;   
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE COPYRIGHT 2012 REMOTE SENSING SYSTEMS.
;   THEY ARE PROVIDED FOR INFORMATIONAL AND ALGORITHM VERIFICATION PURPOSES ONLY
;   AND MAY NOT BE USED IN WHOLE OR IN PART FOR ANY OTHER PURPOSE WITHOUT WRITTEN
;   PERMISSION FROM REMOTE SENSING SYSTEMS.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   5/15/2018 Initial version submitted to NCEI
;
; USAGE
;   load_AMSU_file_locations,/verbose
;
;@*****

pro load_AMSU_file_locations,verbose=verbose

  fortran_file = 'B:\Users\mears\Visual Studio 2008\Projects\AMSU_Modules\Source\AMSU_File_Locations.f90'
	on_ioerror,no_file
	openr,lun,fortran_file,/get_lun

	not_done = 1
	on_ioerror,file_end

	while not_done do begin
		line = ' '
		readf,lun,line,format='(a200)'
		exclam_pos = strpos(line,'!')
		if exclam_pos eq -1 then exclam_pos = 9999
		if (strmatch(line,'*character*',/fold_case) and strmatch(line,'*parameter*',/fold_case) and strmatch(line,'*\\*')) then begin
			; this line appears to be a path specification
			name_pos1 = strpos(line,'::')
			name_pos2 = strpos(line,'=',name_pos1)
			if name_pos1 gt exclam_pos then continue
			name = strcompress(strmid(line,name_pos1+2,name_pos2-name_pos1-2),/remove_all)
			name = '!'+name
			pathx = strcompress(strmid(line,name_pos2),/remove_all)
			x = '''
			path_pos1 = strpos(pathx,x)+1
			path_pos2 = strpos(pathx,x,path_pos1+2)-1
			path = strcompress(strmid(pathx,path_pos1,path_pos2-path_pos1+1),/remove_all)

			if keyword_Set(verbose) then print,name,' is set to ',path
			defsysv,name,path
		endif
	endwhile

	file_end:close,lun
	free_lun,lun
	return

	no_file:message,'Could not file Fortran File location file '+fortran_file

end