;@***h* MLT_V4_RSS/msu_v4_grpt_merge.tmt.pro
; NAME
;   MLT_V4_RSS/msu_v4_grpt_merge.tmt.pro
;
; PURPOSE
;   top level program that performs TMT merge for MSU
;
; DESCRIPTION
;   top level program that performs TMT merge for MSU.  The merging process is described in
;
;   Mears, C. A., & Wentz, F. J. (2016). Sensitivity of Satellite-Derived Tropospheric Temperature
;   Trends to the Diurnal Cycle Adjustment. Journal of Climate, 29, 3629-3646. doi: 10.1175/JCLI-D-15-0744.1
;
;   The program defines several common block, then read in data and performs simple QC analysis to
;   remove data that is too sparse for a given month/satellite.  The program then calculates the various merging parameters.
;   They are:
;     Target Factors
;     Adjustments to the diurnal correction
;     Intersatellite offsets
;
;   The merged data product is then written.
; INPUTS
;   input variables
; OUTPUTS
;   output variable and descriptions
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   1/10/2018 Initial Version prepared for NCDC
;
; USAGE
;   .r MLT_V4_RSS/msu_v4_grpt_merge.tmt.pro
;
;@*****

tb_arr      = 0 
tar_arr     = 0
tb_clim_arr = 0
num_arr     = 0


print_global_pars = 1
fix_colors,colors=colors
!p.background = colors.white
!p.color = colors.black
;goto,skip

initialize_MSU_System_Variables_V4
read_land_fraction_144_72,lf
land_mask = intarr(144,72)
land = where(lf gt 0.5)
land_mask[land] = 1.0
  defsysv,'!MSU_L3_Path',       'M:\MSU_AMSU_Data\AMSU-A_L3\MSU_AMSU_V4\Merge_Monthly_AMSU_FOV_V4\results\TLS_MSU\'
  defsysv,'!MSU_L3_Plot_Path',  'M:\MSU_AMSU_Data\AMSU-A_L3\MSU_AMSU_V4\Merge_Monthly_AMSU_FOV_V4\reports\TLS_MSU\'
  defsysv,'!MSU_L3_Report_Path','M:\MSU_AMSU_Data\AMSU-A_L3\MSU_AMSU_V4\Merge_Monthly_AMSU_FOV_V4\reports\TLS_MSU\'
  log_path    = 'M:\MSU_AMSU_Data\AMSU-A_L3\MSU_AMSU_V4\Merge_Monthly_AMSU_FOV_V4\logs_\TLS_MSU\'
preprocess_rss = 0
ocean_only = 0

perform_TTS_frequency_adjust = 0
perform_TLS_frequency_adjust = 1

fov_list = ['central3','central5','central7','central9']

channels = ['TLT','TMT','TTS','TLS']
process  = [ 0,   0,    0,    1]
eia_model = 'MERRA'
diurnal_models = ['NONE','CCM3','HADGEM','MERRA','CMAM','NONE','CCM3','HADGEM','MERRA','CCM3']

offset_scheme = 'land_ocean_together'

case offset_scheme of
  'land_ocean_together': begin
      offset_scheme_index = 1
  end
    'land_ocean_separate': begin
      offset_scheme_index = 2
  end
    'ocean_only': begin
      offset_scheme_index = 3
  end
endcase
map_stddev_all = fltarr(10,2,3)

tf_schemes = ['land_and_ocean']
foreach tf_scheme,tf_schemes do begin

case tf_scheme of
  'land_and_ocean':begin
    tf_surf = 'Land_and_Sea'
    tf_scheme_index = 1
    zero_tf = 0
   end
  'ocean_only':begin
    tf_surf = 'Sea'
    tf_scheme_index = 2
    zero_tf = 0
   end
   'none':begin
     tf_surf = 'Sea'
     tf_scheme_index = 3
     zero_tf = 1
   end
endcase
   
    
for fov_index = 3,3 do begin
  fov_set = fov_list[fov_index]
case fov_set of
  'central5': begin
    fov_ok = [3,4,5,6,7]
    num_fovs_used = 5
   end
   'central3': begin
    fov_ok = [4,5,6]
    num_fovs_used = 3
   end
   'central7': begin
    fov_ok = [2,3,4,5,6,7,8]
    num_fovs_used = 7
   end
   'central9': begin
    fov_ok = [1,2,3,4,5,6,7,8,9]
    num_fovs_used = 9
   end
endcase
fov_wts = fltarr(11)
fov_wts[fov_ok] = 1.0

tf_zero_wts = [0.5,1.0,2.0,3.0]

for TF_zero_factor_index = 1,1 do begin
  tf_zero_wt = tf_zero_wts[TF_zero_factor_index]

  foreach diurnal_index,[6] do begin
    if diurnal_index eq 4 then continue
  
    adjust_diurnal = 0
  
    if diurnal_index le 4 then begin
      diurnal_model = diurnal_models[diurnal_index]
      modify_diurnal = 0
    endif

    if diurnal_index ge 5 then begin
      adjust_diurnal = 1
      diurnal_model = diurnal_models[diurnal_index]
    endif
    
    if diurnal_index ge 9 then begin
      adjust_diurnal = 2
      diurnal_model = diurnal_models[diurnal_index]
    endif

  
  for channel_index = 0,3 do begin
  	if process[channel_index] gt 0 then begin
  		channel_str = channels[channel_index]
  		if channel_str eq 'TTS' then begin
  		  version_num = (10000*perform_TTS_frequency_adjust) + (1000*offset_scheme_index) + (100*tf_scheme_index)  + (10*num_fovs_used) + diurnal_index
  		endif else begin
  		  version_num = (10000*TF_zero_factor_index) + (1000*offset_scheme_index) + (100*tf_scheme_index)  + (10*num_fovs_used) + diurnal_index
  		endelse
  		
  		if channel_str eq 'TLS' then begin
  		  version_num = (10000L*perform_TLS_frequency_adjust) + (1000*offset_scheme_index) + (100*tf_scheme_index)  + (10*num_fovs_used) + diurnal_index
      endif
      regularization_wt = 3.0
      version_num = version_num +60000L
      version_str = string(version_num,format = '(i5.5)')
      
      ok = check_path(log_path,/create)
      
      report_path = !MSU_L3_Report_Path
      report_path = report_path + version_str +'\'
      ok = check_path(report_path,/create)

      
  		print,'Version Number = ',version_num
  		defsysv,'!log_lun',2
  		log_file = string(log_path,channel_str,version_num,format='(a,"merge_log_fov_amsu_channel_",a,"_v4.",i5.5,".log.txt")')
  		close,!log_lun
  		openw,!log_lun,log_file
      read_msuv4_months_to_exclude,channel_str,months_to_use_v4,error	
       
  		tb_arr = !values.f_nan
  		tb_arr_adj = !values.f_nan
  		adjustment_flag = 7 ; setting this flag to this value for the netcdf write routine -- has no other effect

  		read_all_adjusted_MSU_maps_from_FOV,    channel_str = channel_str,           $
                                              diurnal_model = diurnal_model,       $
                                              eia_model = eia_model,               $
                                              fov_ok = fov_ok,                     $
                                              tb_arr = tb_arr,                 $
                                              tar_arr = tar_arr,               $
                                              num_arr = num_arr,               $
                                              file_list=file_list,             $
                                              raw_tb_arr = tb_Arr_raw,         $
                                              modify_diurnal = 0, use_star = use_star
                                     	
  		sz = size(tb_arr,/dimensions)
  		num_months = sz[2]
  		num_sats = sz[3]
  		
  		num_thres = num_fovs_used*5.0
  		if channel_str eq 'TLT' then num_thres = 64
  		months_to_use = months_to_use_V4
  		months_to_use[24,1] = 1
  		months_to_use[39,1] = 1
  		months_to_use[85,2] = 1
  		months_to_use[130,6] = -1
  		
  		calc_TF_from_grpt_maps_v4,  tb_arr,         $
  		  tar_arr,        $
  		  num_arr,        $
  		  channel_str,        $
  		  sats_to_use,      $
  		  target_factors,     $
  		  target_means,     $
  		  offsets,        $
  		  months_to_use,      $
  		  num_thres=num_thres, $
  		  trop_tb_arr = trop_tb_arr,  $
  		  trop_tar_arr = trop_tar_arr, $
  		  surf_str = tf_Surf,  $
  		  tf_zero_wt=tf_zero_wt  ; only matters for TLT

  		
  		if ((channel_str eq 'TLS') and (perform_TLS_frequency_adjust eq 1)) then begin
  		  ;--------------------------------------
  		  ;  Perform Ad-Hoc Frequency adjustment
  		  ;--------------------------------------
  		  log,'Performing Frequency Shift Adjustment for TLS'
  		  
  		  TLS_freq_adj_clim_file = 'B:\MSU_AMSU\IDL_MSU_AMSU_V4\Merge_Monthly_MSU_FOV_V4\MSU_V4_Freq_Adj\MSU_TLS_20_20_month_lat.sav'
        restore,TLS_freq_adj_clim_file,/verbose
        
        mean_zonal_freq_adjust = rebin(TIME_LAT_DIFF_CLIM,72,12)
        zonal_freq_adjust_to_plot =  fltarr(72,336)
        for y = 0,27 do begin
          zonal_freq_adjust_to_plot[*,y*12:11+y*12] = mean_zonal_freq_adjust
        endfor

        optimize_freq_adjustments_TLS,tb_arr,num_arr,months_to_use,zonal_freq_adjust_to_plot,freq_adjust_factor_opt
        tb_arr_freq_adj = tb_arr
        for satnum = 0,8 do begin
          freq_adjust_factor = [0.0,0.0,0.0,0.0,freq_adjust_factor_opt[0],freq_adjust_factor_opt[1],freq_adjust_factor_opt[2],freq_adjust_factor_opt[3],0.0]
          for m = 0,num_months-1 do begin
            for ilon = 0,143 do begin
              tb_Arr_freq_adj[ilon,*,m,satnum] = tb_Arr[ilon,*,m,satnum] + freq_adjust_factor[satnum]*mean_zonal_freq_adjust[*,m mod 12]
            endfor
          endfor
        endfor
        tb_arr = tb_arr_freq_adj
      endif
  		
  		if ((channel_str eq 'TTS') and (perform_TTS_frequency_adjust eq 1)) then begin
    		;--------------------------------------
    		;  Perform Ad-Hoc Frequency adjustment
    		;--------------------------------------
    		log,'Performing Frequency Shift Adjustment for NOAA-12 and NOAA-14'
    		TTS_Freq_adjust_file = 'B:\MSU_AMSU\IDL_MSU_AMSU_V4\Merge_Monthly_MSU_FOV_V4\Investigate_MSU3\TTS_Freq_Shift_adjustment.sav'
    		restore,TTS_Freq_adjust_file
    		
    		mean_zonal_freq_adjust = fltarr(72,12)
    		fov_relative_center = abs(fov_ok - 5)
    		for k = 0,n_elements(fov_ok)-1 do begin  		  
    		  mean_zonal_freq_adjust = mean_zonal_freq_adjust + MEAN_ZONAL_TB_DIFF[*,fov_relative_center[k],*]
    		endfor
    		mean_zonal_freq_adjust = mean_zonal_freq_adjust/n_elements(fov_ok)
    		
    		
    		for satnum = 7,8 do begin
    		  for m = 0,num_months-1 do begin
    		    for ilon = 0,143 do begin
    		      tb_Arr[ilon,*,m,satnum] = tb_Arr[ilon,*,m,satnum] + freq_adjust_factor*mean_zonal_freq_adjust[*,m mod 12]
    		    endfor
    		  endfor
    		endfor	
  		endif
  		
  		; find the target factors from grid_point data.  The adjusted data is returned in tb_arr_adj.
  		; the target factors are contained in the merge_parameters variable..
  		
      num_thres = num_fovs_used*5.0
      if channel_str eq 'TLT' then num_thres = 64
  		months_to_use = months_to_use_V4
      months_to_use[24,1] = 1
      months_to_use[39,1] = 1
      months_to_use[85,2] = 1
      months_to_use[130,6] = -1

  		calc_TF_from_grpt_maps_v4,  tb_arr,         $
  		  tar_arr,        $
  		  num_arr,        $
  		  channel_str,        $
  		  sats_to_use,      $
  		  target_factors,     $
  		  target_means,     $
  		  offsets,        $
  		  months_to_use,      $
  		  num_thres=num_thres, $
  		  trop_tb_arr = trop_tb_arr,  $
  		  trop_tar_arr = trop_tar_arr, $
  		  surf_str = tf_Surf,  $
  		  tf_zero_wt=tf_zero_wt  ; only matters for TLT
  		  
      
  		save,file = 'B:\MSU_AMSU\IDL_MSU_AMSU_V4\diur_sensitivity\msu_tar_arr.sav',tar_arr,num_arr,months_to_use
 		  
  		if channel_str eq 'TTS' then target_factors[0:4] = !values.f_nan
  		;experimental
  		;target_factors[8] = 0.02237
  		
  		if keyword_set(zero_tf) then target_factors = fltarr(9)
  		
  		if keyword_Set(print_global_pars) then begin
  		  log,string(target_factors,format = '("target_Factors = [",8(f8.4,","),f8.4,"]")')
  		  log,string(target_means,format = '("target_means = [",8(f8.4,","),f8.4,"]")')
  		  log,string(offsets,format = '("offsets = [",8(f8.4,","),f8.4,"]")')
  		endif
  		

      apply_TF_to_grpt_maps_v4,tb_arr,tar_arr,channel_str,target_factors,target_means,months_to_use,tb_arr_adj
      apply_TF_to_grpt_maps_v4,tb_arr_raw,tar_arr,channel_str,target_factors,target_means,months_to_use,tb_arr_raw_adj
  		
  		if adjust_diurnal eq 1 then begin
  	    set_Win
 
  	    ; for TLT and TMT, we use separate diurnal adjustments for land and ocean
  	    ; for TTS and TLS, the land and ocean differences are not used, resultsing in one less 
  	    ; array dimension
  	    
  	    if ((channel_str eq 'TLT') or (channel_str eq 'TMT')) then begin
  		    diurnal_residual_parameters_MSU = fltarr(15,2,72)
  		  endif

  		  if  ((channel_str eq 'TTS') or (channel_str eq 'TLS')) then begin
  		    diurnal_residual_parameters_MSU = fltarr(15,72)
  		  endif
       
        for ilat = 0,71 do begin
  		    lat_range = [-90.0 + 2.5*(ilat-2),-90.0 + 2.5*(ilat+3)]
  		    if ((channel_str eq 'TMT') or (channel_str eq 'TLT')) then begin 

            fit_residual_diurnal_MSU_w_seasonal,tb_arr_adj,lat_range,params
  		      print,lat_range,params
  		      if ilat le 17 then begin
  		        params[*,1] = params[*,0]
  		      endif
  		      diurnal_residual_parameters_MSU[*,*,ilat] = params[*,0:1]
   		    endif

  		    if ((channel_str eq 'TTS') or (channel_str eq 'TLS')) then begin
  		      if ilat eq 1 then log,'Calculating Seasonally modulated diurnal adjustments'
            ;fit_residual_diurnal_MSU_w_seasonal,tb_arr_adj,lat_range,params_w_season
            fit_residual_diurnal_MSU_w_seasonal,tb_arr_adj,lat_range,params_w_season,regularization_wt=regularization_wt
 		        print,lat_range,params_w_season
 		        diurnal_residual_parameters_MSU[*,ilat] = params_w_season[*,2]
   		    endif
  	  	endfor
  		  save_file = string(channel_str,version_num,format='("B:\MSU_AMSU\IDL_MSU_AMSU_V4\Merge_Monthly_MSU_FOV_V4\MSU_V4_Diurnal\diurnal_parameters\msu_diurnal_residual_parameters_chan_",a,"_v",i5.5,".sav")')
  		  save,file=save_file,diurnal_residual_parameters_MSU
  		  log,'Saving Diurnal Adjustment Parameters'
  		  log,save_file
  		  apply_diurnal_fit_residuals_MSU,tb_arr_adj,diurnal_residual_parameters_MSU,tb_arr_temp
        tb_arr_adj2 = tb_arr_temp
        plot_MSU_diurnal_adjustments_TLS,tb_arr_raw_adj,tb_arr_adj,tb_Arr_adj2,version_num,report_path
        tb_arr_adj = tb_Arr_adj2
        
        plot_diurnal_parameters_TLS,diurnal_residual_parameters_MSU,plot_path = report_path
  		endif
  		
  		if adjust_diurnal eq 2 then begin
  		  ; get the adjustment parameters from AMSU
  		  channel_Str_AMSU = 'TLS'
  		  version_num_AMSU = 151156L
  		  save_file = string(channel_str,_AMSU,channel_str,version_num_AMSU,format='("M:\MSU_AMSU_Data\AMSU-A_L3\MSU_AMSU_V4\Merge_Monthly_AMSU_FOV_V4\reports\",a,"\",i7.7,"\diurnal_residual_parameters_chan_",a,"_v",i7.7,".sav")')
  		  print,save_file
  		  restore,save_file,/verbose    ;diurnal_residual_parameters
  		 
;  		  diurnal_residual_parameters[0:7,*,*] = 0.0
;  		  diurnal_residual_parameters[*,1,0:17] = diurnal_residual_parameters[*,0,0:17]
  		  
  		  apply_diurnal_fit_residuals_MSU,tb_arr_adj,diurnal_residual_parameters,tb_arr_temp
  		  tb_arr_adj2 = tb_arr_temp
        plot_MSU_diurnal_adjustments_TLS,tb_arr_raw_adj,tb_arr_adj,tb_Arr_adj2,version_num,report_path
  		  tb_arr_adj = tb_arr_adj2

  		endif
      
      ;ps_file =string(!MSU_L3_Plot_Path,version_str,channel_str,channel_str,version_num,format='(a,a,"\",a,"_msu_grpt_merge_v2_report.",i5.5,".ps")')
  		;log,'Postscript file = '+ps_file
  		;set_up_ps,xsize=7.0,ysize=9.0,file = ps_file

      
      calc_offsets_from_grpt_maps_v4,tb_arr_adj,months_to_use,offsets
      smooth_offsets,offsets,offsets_smooth
      apply_offsets_to_grpt_maps_v4,tb_arr_adj,offsets_smooth
      calc_tb_clim_Arr,tb_arr_adj,months_to_use,tb_clim_arr
      
  		; find tb_anom factors from the gridded data
  		tb_arr_no_tbf = tb_arr_Adj
  		tb_arr_no_tbf[*,0:2,*,*] = !values.f_nan
  		tb_arr_no_tbf[*,69:71,*,*] = !values.f_nan
  		tb_arr_no_tbf = tb_arr_Adj
  		calc_single_TbF_from_grpt_map_v4,tb_arr_adj,tb_clim_arr,months_to_use,tb_factors;,plt_tb_factors =plt_tb_factors
 
  		save_file =string(!MSU_L3_Plot_Path,channel_str,version_num,format='(a,"adjusted_tbs_",a,"_v",i7.7,".sav")')
  		print,'Adjusted Tb save file: '+save_file
      save,file = save_file,tb_arr_adj
                                 
  		;print,'stddev map_metrics = ',map_metrics
  		;map_stddev_all[diurnal_index,tf_scheme_index-1,*] = map_metrics
  		tb_arr_merged = replicate(!values.f_nan,144,72,336)
  		print,'Merging'
  		pixel_thres = 10
  		for i = 0,num_months-1 do begin
  			tot_tb = fltarr(144,72)
  			tot_num = fltarr(144,72)
  			for satnum = 0,8 do begin
  				if months_to_use[i,satnum] lt 1 then continue
  				tb = tb_arr_adj[*,*,i,satnum]
  				num = num_arr[*,*,i,satnum]
  				ok = where((finite(tb) gt 0) and (num gt pixel_thres),ct)
  				if ct gt 5000 then begin
  					tot_tb[ok] = tot_tb[ok] + tb[ok]*num[ok]
  					tot_num[ok] = tot_num[ok] + num[ok]
  				endif
  			endfor ; satnum
  			tb_merged = tot_tb/tot_num
  			tb_arr_merged[*,*,i] = tb_merged
  		endfor
  
  		tb_arr_merged[*,*,324:335] = !values.f_nan
  		tb_arr_merged[*,*,0:9] = !values.f_nan
  
  		tf_array = fltarr(72,9)
  		tbf_Array = fltarr(72,9)
  		for ilat = 0,71 do begin
  			tf_array[ilat,*]  = target_factors
  			tbf_array[ilat,*] = tb_factors
  		endfor
	
  		log,'Writing netcdf file'
  		
    ; expand merge coefficients to maps for metadata
  		offset_arr = replicate(!values.f_nan,144,72,num_sats)
  		tarmult_arr = replicate(!values.f_nan,144,72,num_sats)
  		tbmult_arr = fltarr(144,72,num_sats)
  		
  		
  		;need to fix this eventually - -just expanding offsets for metadata.
  		for sat = 0,num_sats-1 do begin
  		  tarmult_arr[*,*,sat] = target_factors[sat]
  		  tbmult_arr[*,*,sat]  = tb_factors[sat]
  		endfor
  		
  		sz_offsets = size(offsets,/dimensions)
  		
  		if n_elements(sz_offsets) eq 2 then begin
    		for ilon = 0,143 do begin
    		  offset_arr[ilon,*,*] = offsets
    		endfor
    	endif else begin  ; sz offsets should be [72,9,2]
    	 bad = where(finite(offsets[*,*,1]) eq 0,ct)
    	 if ct gt 0 then begin
    	   temp1 = offsets[*,*,1]
    	   temp2 = offsets[*,*,0]
    	   temp1[bad] = temp2[bad]
    	   offsets[*,*,1] = temp1
    	 endif
    	 for sat = 0,num_sats-1 do begin
    	  for ilat = 0,71 do begin
    	    offset_arr[*,ilat,sat] = offsets[ilat,sat,0]*(1.0-lf[*,ilat]) + offsets[ilat,sat,1]*lf[*,ilat]
    	  endfor
    	 endfor
    	endelse
  								
  	  write_msu_only_merged_Tbs_144_72_netcdf_4_0,     $
  								  Tbs_144_72 = tb_arr_merged ,   $
  								  channel_str=channel_str,    $
  								  version_num=version_num,    $
  								  diurnal_model = diurnal_model,    $
  								  eia_model = eia_model,            $
  								  fov_wts = fov_wts,                     $
  								  node_wts = [1.0,1.0],                   $
  								  adjustment_flag = adjustment_flag,      $
  								  offsets = offset_arr,        $
  								  target_factors = tarmult_arr, $
  								  target_means = target_means,           $
  								  tb_factors = tbmult_arr,        $
  								  months_used = months_to_use,             $
  								  date_L2C_processed = date_L2C_processed,  $
  								  output_path = !MSU_L3_Path

  	endif
  endfor
endforeach
endfor
endfor


endforeach
;endfor
end