pro read_MSU_monthly_map_by_fov,satnum,channel,year,month,tb_arr,err,tb_hist=tb_hist,tb_range=tb_range,verbose=verbose,file=file

  ;@***h* MLT_RSS/read_MSU_monthly_map_by_fov.pro
  ;
  ; NAME
  ;   read_MSU_monthly_map_by_fov.pro
  ;
  ; PURPOSE
  ;   reads a single month of MSU dat in gridded map by FOV form
  ;
  ; DESCRIPTION
  ;   reads a single month of MSU dat in gridded map by FOV form.  
  ;   
  ; INPUTS
  ;   satnum          int   satellite number (1..9 for MSU)
  ;   channel         int   channel number
  ;   year            int   year of month to be read
  ;   month           int   month to be read
  ;   verbose         int   set to non-zero value to have routine print file name to be read
  ;   
  ; OUTPUTS
  ;   tb_arr          flt32 (num_data_types,num_nodes,num_fov,num_lons,num_lats),2,11,144,72)
  ;   tb_hist         flt32 (num_fovs,num_tb_bins), optional   histogram of tb values, in 1 K bins, from 0 to 299.
  ;   tb_range        flt32 (2), optional range of brightness temperatures
  ;   file            string,optional  name of file read.
  ;
  ;
  ; AUTHOR
  ;   Carl Mears, Remote Sensing Systems
  ;
  ; COPYRIGHT
  ;   THIS SOFTWARE AND ITS DOCUMENTATION ARE COPYRIGHT 2012 REMOTE SENSING SYSTEMS.
  ;   THEY ARE PROVIDED FOR INFORMATIONAL AND ALGORITHM VERIFICATION PURPOSES ONLY
  ;   AND MAY NOT BE USED IN WHOLE OR IN PART FOR ANY OTHER PURPOSE WITHOUT WRITTEN
  ;   PERMISSION FROM REMOTE SENSING SYSTEMS.  THEY ARE FURNISHED "AS IS." THE
  ;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
  ;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
  ;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
  ;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
  ;   TO USERS.
  ;
  ; HISTORY
  ;   3/29/2012 Initial Version prepared for NCDC
  ;
  ; USAGE
  ;   read_MSU_monthly_map_by_fov,satnum,channel,year,month,tb_arr,err,tb_hist=tb_hist,tb_range=tb_range,verbose=verbose,file=file
  ;
  ;@*****
  
  if ((satnum lt 1) or (satnum gt 9)) then begin
    print,'Satnum '+string(satnum)+' is not an MSU instrument'
    err = -1
    return
  endif
  
  if satnum eq 5 then begin
    if channel eq 2 then begin
      if (((year eq 1987) and (month ge 3)) or (year ge 1988)) then begin
        ; bad months for NOAA-09, channel 2 after feb 1987
        tb_arr = replicate(!values.f_nan,4,2,11,144,72)
        tb_hist = replicate(!values.f_nan,11,300)
        err = -1
        return
      endif
    endif
  endif
  
  satellite_name = sat_name(satnum,/fill)
  file = string(channel,satellite_name,year,month,format='("M:\MSU_AMSU_Data\MSU_L2C\Monthly_Maps_v4\MSU_Channel_",i2.2,"\fov_maps\",a,"\tb_no_adj\y",i4.4,"_m",i2.2,"_fov_hist_144_72_v4_01.dat")')

  close,3
  on_ioerror,io_error
  info = file_info(file)
  if info.exists gt 0 then begin
    openr,3,file
    month2 = 0L
    year2 = 0L
    channel2 = 0L
    tb_arr = fltarr(4,2,11,144,72)
    readu,3,month2,year2,channel2,tb_arr
    if info.size gt 3649549L then begin
      tb_hist = fltarr(11,300)
      readu,3,tb_hist
    endif else begin
      tb_hist = replicate(!values.f_nan,11,300)
    endelse
  endif else begin
    if keyword_set(verbose) then print,'Unable to open '+file
    tb_arr = replicate(!values.f_nan,4,2,11,144,72)
    tb_hist = replicate(!values.f_nan,11,300)
    err = -1
    return
  endelse
  
  close,3
  err = 0
  return
  
  io_error:
    err = -1
    tb_arr = replicate(!values.f_nan,4,2,11,144,72)
    tb_hist = replicate(!values.f_nan,11,300)
end