;@***h* MLT_RSSv4/read_msuv2_months_to_exclude.pro
;
; NAME
;   read_msuv2_months_to_exclude.pro
;
; PURPOSE
;   reads a list of MSU satellite months to exclude
;
; DESCRIPTION
;   reads a list of MSU satellite months to exclude
;
; INPUTS
;   channel_str     string containing channel name, e.g. 'TLT','TMT','TTS','TLS'
;
; OUTPUTS
;   months_to_use   integer array.  
;   error           error flag.  non-zero value indicates error condition.
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE COPYRIGHT 2012 REMOTE SENSING SYSTEMS.
;   THEY ARE PROVIDED FOR INFORMATIONAL AND ALGORITHM VERIFICATION PURPOSES ONLY
;   AND MAY NOT BE USED IN WHOLE OR IN PART FOR ANY OTHER PURPOSE WITHOUT WRITTEN
;   PERMISSION FROM REMOTE SENSING SYSTEMS.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   10/30/2013 Initial version written
;
; USAGE
;   read_msuv2_months_to_exclude,'TMT',months_to_use,error
;
;@*****
;
pro read_msuv4_months_to_exclude,channel_str,months_to_use,error
   
  case channel_str of
    'TLT' : channel = 2
    'TMT' : channel = 2
    'TTS' : channel = 3
    'TLS' : channel = 4
  endcase
  sat_names = ['TIROS-N','NOAA-06','NOAA-07','NOAA-08','NOAA-09','NOAA-10','NOAA-11','NOAA-12','NOAA-14']
  if channel_str eq 'TLT' then begin
    exclude_file = "M:\MSU_AMSU_Data\MSU_L2C\Monthly_Maps_V4\MSU_Channel_02\tlt_maps\months_to_exclude_"+channel_str+'.txt'
  endif else begin
    exclude_file = string(channel,format = '("M:\MSU_AMSU_Data\MSU_L2C\Monthly_Maps_V4\MSU_Channel_",i2.2,"\fov_maps\months_to_exclude_")')+channel_str+'.txt'
  endelse
  months_to_use = intarr(336,9)
  error = 0
  on_ioerror,no_file
  close,3
  openr,3,exclude_file
  
  on_ioerror,file_end
  
  while 1 do begin
    line = '      '
    readf,3,line
    
    
    ; check to see if it is a comment
    if strmid(line,0,1) eq '#' then continue
    
    ; split the string up
    
    strings = strsplit(line,/extract)
    if n_elements(strings) ne 3 then continue
    sat_num = where(strings[0] eq sat_names)
    
    
    year = fix(strings[1])
    
    month = fix(strings[2])
    
    
    month_i = 12*(year-1978)+month-1
    if ((month_i ge 0) and (month_i le 335) and (sat_num ge 0) and (sat_num le 8)) then begin
      months_to_use[month_i,sat_num] = -1
    endif else begin
      print,'Error:  month num or sat num out of range in read msuv2_months_to_exclude
    endelse
  endwhile
  
  no_file:
    error = -1
  
  file_end:
  
  
  
  end
    
    