
import os
import string
import time
import calendar
import types
import sys
import os.path
import shutil


##@***h* MLT_V4_RSS/log_message
## NAME
##   MLT_V4_RSS/log_message
##
## PURPOSE
##   writes message to log file specified by log_ID
##
## DESCRIPTION
##   writes message to log file specified by log_ID
##
## INPUTS
##   msg		string: message to be written
##	 log_ID		file_handle:  ID of log file to be written
##	 flush		boolean:      if true log all staged text is flushed ot the file
##
## OUTPUTS
##   none
##
## AUTHOR
##   Marty Brewer, Remote Sensing Systems
##
## COPYRIGHT
##   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
##   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
##   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
##   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
##   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
##   THE USE OF THE SOFTWARE AND DOCUMENTATION## OR (2) TO PROVIDE TECHNICAL SUPPORT
##   TO USERS.
##
## HISTORY
##   4/10/2018 Initial Version prepared for NCDC
##
## USAGE
##   log_message('Hello Log File',log_ID,flush)
##
##@*****

def log_message(msg,log_ID,flush):
        if type(msg) is types.StringType:
                if msg != '\n': msg = time.asctime() + '   ' + msg
                l = len(msg)
                if msg[l-1:l] == '\n':
                        log_ID.write(msg)
                else:
                        log_ID.write(msg + '\n')
                print msg


        if type(msg) is types.ListType:
                for lyn in msg: print lyn; log_ID.write(lyn + '\n');


        if flush: log_ID.flush()

##@***h* MLT_V4_RSS/convert_amsu_l1b_to_l2a
## NAME
##   MLT_V4_RSS/convert_amsu_l1b_to_l2a
##
## PURPOSE
##   driver program that converts AMSU L1B data to L2A
##
## DESCRIPTION
##   driver program that converts AMSU L1B data to L2A
##   program calls fortran executeable AMSU_L1B_to_L2A.exe
##   this executable is made using the fortran code in the ../fortran/AMSU_L1B_to_L2A folder
##
## INPUTS
##   channel_str	string containing the channel name
##   sat_num_str    string containing the satellite number
##   log_ID			ID of the log file to be written
##
## OUTPUTS
##   none
##
## AUTHOR
##   Carl Mears, Remote Sensing Systems
##
## COPYRIGHT
##   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
##   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
##   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
##   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
##   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
##   THE USE OF THE SOFTWARE AND DOCUMENTATION## OR (2) TO PROVIDE TECHNICAL SUPPORT
##   TO USERS.
##
## HISTORY
##   4/10/2018 Initial Version prepared for NCDC
##
## USAGE
##   convert_amsu_l1b_to_l2a('05','17',log_ID)
##
##@*****
def convert_amsu_l1b_to_l2a(channel_str,sat_num_str,log_ID):

    L2A_LOG_PATH     = 'm:/MSU_AMSU_Data/AMSU-A_L2A/L1B_to_L2A_logs/'

    log_message('Converting AMSU L1B to L2A'+'\n',log_ID,1)
    log_message('Sat Num = '+sat_num_str+' Channel = '+channel_str,log_ID,1)
    

    L = ['C:/msu_amsu/msu_amsu_v33/python/Process_NOAA_Orbits/fortran_executables/AMSU_L1B_to_L2A.exe',sat_num_str,channel_str]
    success = os.spawnv(os.P_WAIT,'C:/msu_amsu/msu_amsu_v40/python/Process_NOAA_Orbits/fortran_executables/AMSU_L1B_to_L2A.exe',L)

    if success != 0:
            log_message('Problem Generating L2A files',log_ID,1)
            sys.exit(success)

##@***h* MLT_V4_RSS/orbitify_amsu_saa_files
## NAME
##   MLT_V4_RSS/orbitify_amsu_saa_files
##
## PURPOSE
##   driver program that assembles AMSU files from CLASS into orbits
##
## DESCRIPTION
##   driver program that assembles AMSU files from CLASS into orbits
##   program calls fortran executeable AMSU_L1B_to_L2A.exe
##   this executable is made using the fortran code in the ../fortran/AMSU_Orbitification folder
##
## INPUTS
##   channel_str	string containing the channel name
##   sat_num_str    string containing the satellite number
##   log_ID			ID of the log file to be written
##
## OUTPUTS
##   none
##
## AUTHOR
##   Carl Mears, Remote Sensing Systems
##
## COPYRIGHT
##   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
##   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
##   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
##   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
##   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
##   THE USE OF THE SOFTWARE AND DOCUMENTATION## OR (2) TO PROVIDE TECHNICAL SUPPORT
##   TO USERS.
##
## HISTORY
##   4/10/2018 Initial Version prepared for NCDC
##
## USAGE
##   orbitify_amsu_saa_files(log_ID,sat_num_str,log_fyl)
##
##@*****

def orbitify_amsu_saa_files(log_ID,sat_num_str,log_fyl):


    ORBIT_LOG_PATH     = 'm:/MSU_AMSU_Data/AMSU-A_L1A/amsu_orbit_logs/'
    AMSU_NOAA_15_PATH  = 'm:/MSU_AMSU_Data/AMSU-A_L1A/NOAA-15/'
    AMSU_NOAA_16_PATH  = 'm:/MSU_AMSU_Data/AMSU-A_L1A/NOAA-16/'
    AMSU_NOAA_17_PATH  = 'm:/MSU_AMSU_Data/AMSU-A_L1A/NOAA-17/'
    AMSU_NOAA_18_PATH  = 'm:/MSU_AMSU_Data/AMSU-A_L1A/NOAA-18/'
    AMSU_NOAA_19_PATH  = 'm:/MSU_AMSU_Data/AMSU-A_L1A/NOAA-19/'
    AMSU_AQUA_PATH  =    'm:/MSU_AMSU_Data/AMSU-A_L1A/AQUA/'
    AMSU_METOP_A_PATH  = 'm:/MSU_AMSU_Data/AMSU-A_L1A/METOP-A/'
    AMSU_METOP_B_PATH  = 'm:/MSU_AMSU_Data/AMSU-A_L1A/METOP-B/'
    
    sat_names = ['NOAA-15','NOAA-16','NOAA-17','NOAA-18','METOP-A','AQUA','NOAA-19','METOP-B']
    sat_name = sat_names[int(sat_num_str)-10]
    log_ID = open(log_fyl, 'a')
    log_message('Starting Orbitification for satellite# '+sat_num_str,log_ID,1)
    
    # Orbitify incoming SAA files

    L = ['C:/msu_amsu/msu_amsu_v40/python/Process_NOAA_Orbits/fortran_executables/amsu_orbitify.exe',sat_num_str,log_fyl]
    print L
    log_ID.close()
    success = os.spawnv(os.P_WAIT,'C:/msu_amsu/msu_amsu_v33/python/Process_NOAA_Orbits/fortran_executables/amsu_orbitify.exe',L) 
    # the os.P_wait means wait until process is done
    log_ID = open(log_fyl, 'a')
    if success != 0:
        log_message('Problem orbitifying MSU data... check the orbitification log',log_ID,1)
        sys.exit(success)

    log_message('Orbitification Successful for satellite# '+sat_num_str,log_ID,1)
            

    # evaluate the most recent orbitification log, and move the
    # files that have been successfully orbitified
    # into the archive folders
    ORBIT_LOG_PATH = ORBIT_LOG_PATH+'/'+sat_name+'/'
    orbit_logs = os.listdir(ORBIT_LOG_PATH)
    num_logs = len(orbit_logs)
    orbit_logs.sort()
    orbit_log_file = ORBIT_LOG_PATH+orbit_logs[num_logs-1]
    orbit_log_ID = open(orbit_log_file, 'r')
    
    lines = orbit_log_ID.readlines()
    orbit_log_ID.close
        
    for line in lines:
        if len(line) > 27:
            # maybe this is the name of a file
            NSS_location = string.find(line,'NSS.A')
            if NSS_location >= 0:  # it IS a SAA NOAA-14 filename -- copy to archive location

                # determine satellite and path                
                sat_str = line[NSS_location+9:NSS_location+11]
                if sat_str == 'NK':
                    path = AMSU_NOAA_15_PATH
                if sat_str == 'NL':
                    path = AMSU_NOAA_16_PATH
                if sat_str == 'NM':
                    path = AMSU_NOAA_17_PATH
                if sat_str == 'NN':
                    path = AMSU_NOAA_18_PATH
                if sat_str == 'NP':
                    path = AMSU_NOAA_19_PATH
                if sat_str == 'M2':
                    path = AMSU_METOP_A_PATH
                if sat_str == 'M1':
                    path = AMSU_METOP_B_PATH
                
                if line[NSS_location -1] == ' ':  ## Number before NSS was stripped from this file name
                    file_to_copy = line[NSS_location:NSS_location+42]
                else:
                    file_to_copy = line[NSS_location-11:NSS_location+42]
                ## for short versions of the file name, there is some junk at the end
                ## remove it
                WS_location = string.find(file_to_copy,' ')
            
                if WS_location > 0:
                    print 'WS_location = '+str(WS_location)
                    file_to_copy = file_to_copy[0:WS_location]
                
                if len(file_to_copy) > 40:
                    print file_to_copy
                    yr_str = line[NSS_location+13:NSS_location+15]
                    source_file = path+file_to_copy
                    destination_file = path + '20'+yr_str+'_archive/'+file_to_copy
                    ##log_message('trying: '+str(source_file),log_ID,1)
                    if not os.path.exists(destination_file):
                        log_message( 'archiving '+str(file_to_copy)+' to '+str(destination_file),log_ID,1)
                        shutil.copy2(source_file,destination_file)
                    if os.path.exists(destination_file):
                        if os.path.exists(source_file):
                            # we assume this means the copy went OK, or the file was already there
                            log_message( 'removing '+str(file_to_copy),log_ID,1)
                            os.remove(source_file)
                    else:
                        log_message('error copying '+str(source_file),log_ID,1)
        if len(line) > 46:
            if line[0:15] == 'Files Processed':
                
                string1 = line[16:23]
                string2 = line[39:len(line)-1]
                log_message('Satellite# '+sat_num_str+' Orbitification: '+string1+' Level 1A files were processed',log_ID,1)
                log_message('Satellite# '+sat_num_str+' Orbitification: '+string2+' Level 1B files were written',log_ID,1)
                log_message('Satellite# '+sat_num_str+' Orbitification: '+string1+' Level 1A files were processed',sum_ID,1)
                log_message('Satellite# '+sat_num_str+' Orbitification: '+string2+' Level 1B files were written',sum_ID,1)
                          
        
        
    orbit_log_ID.close()

	
##@***h* MLT_V4_RSS/create_amsu_l2a_update_lists
## NAME
##   MLT_V4_RSS/create_amsu_l2a_update_lists
##
## PURPOSE
##   creates a list of orbits to update
##
## DESCRIPTION
##   creates a list of orbits to update
##
## INPUTS
##   sat_names				list of satellite names to process
##	 channel_list			list of channels to process
##	 start_orbit_list		list of orbit numbers to start evaluation
##   log_ID					ID of the log file to be written
##
## OUTPUTS
##   writes two files.  One contain the number of orbtis to process, and the second contains a list of orbits to process
##
## AUTHOR
##   Carl Mears, Remote Sensing Systems
##
## COPYRIGHT
##   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
##   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
##   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
##   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
##   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
##   THE USE OF THE SOFTWARE AND DOCUMENTATION## OR (2) TO PROVIDE TECHNICAL SUPPORT
##   TO USERS.
##
## HISTORY
##   4/10/2018 Initial Version prepared for NCDC
##
## USAGE
##   create_amsu_l2a_update_lists(sat_names,channel_list,start_orbit_list,log_ID,sum_ID,debug)
##
##@*****
def create_amsu_l2a_update_lists(sat_names,channel_list,start_orbit_list,log_ID,sum_ID,debug):
    
    amsu_level_1_root  = 'm:\\MSU_AMSU_Data\\AMSU-A_L1B\\'
    amsu_level_2a_root = 'm:\\MSU_AMSU_Data\\AMSU-A_L2A\\'
    temp_root          = 'c:\\temp\\'
    separator = '\\'
    log_message('Updating L2A files',sum_ID,1)
    log_message('Ch'       +'   '+'Sat    '+'   '+'Number to Update',sum_ID,1)
    

    for channel_str in channel_list:
        for sat_name_index in range(len(sat_names)):
            sat_name = sat_names[sat_name_index]
            range_start = start_orbit_list[sat_name_index]

            sat_folder  = sat_name+separator
            sat_folder2  = sat_name+separator
            
            channel_folder = 'Channel_'+channel_str+separator

            list_of_revs_to_process_path = amsu_level_1_root + sat_folder + 'Channel_'+channel_str+'_revs_to_process.txt'
            revlist_file = open(list_of_revs_to_process_path,'w')

            number_of_revs_to_process_path = amsu_level_1_root + sat_folder + 'Channel_'+channel_str+'_number_to_process.txt'
            number_file = open(number_of_revs_to_process_path,'w')
            
            tot_number_to_update = 0
            for rev_start   in range(range_start,108000,5000):
                rev_folder  = 'r'+string.zfill(rev_start+1,5)+'_'+string.zfill(rev_start+5000,5)+separator
                if  rev_start == 95000:
                    rev_folder  = 'r'+string.zfill(rev_start+1,5)+'_'+string.zfill(rev_start+5000,6)+separator
                if  rev_start >= 100000:
                    rev_folder  = 'r'+string.zfill(rev_start+1,6)+'_'+string.zfill(rev_start+5000,6)+separator
                   
                amsu_level_1_path = amsu_level_1_root + sat_folder + rev_folder
##               log_message('Investigating '+amsu_level_1_path,log_ID,1)
                number_to_update = 0
                amsu_level_2a_path = amsu_level_2a_root + sat_folder2 + channel_folder + rev_folder

                level_1_dir_file_name  = temp_root + 'dir_l1b.txt'
                level_1_command = 'dir '+amsu_level_1_path+ ' /T:W /O:N >'+level_1_dir_file_name
                level_2_dir_file_name = temp_root + 'dir_l2a.txt'
                level_2_command = 'dir '+amsu_level_2a_path+' /T:W /O:N >'+level_2_dir_file_name

                log_message(level_1_command,log_ID,1)
                log_message(level_2_command,log_ID,1)
                
                success = os.system(level_1_command)
                success = os.system(level_2_command)

                level_1_dir_file  = open(level_1_dir_file_name ,'r')
                level_1_lines = level_1_dir_file.readlines()
                level_1_dir_file.close
                level_2_dir_file  = open(level_2_dir_file_name ,'r')
                level_2_lines = level_2_dir_file.readlines()
                level_2_dir_file.close

                num_level_1_lines = len(level_1_lines)
                num_level_2_lines = len(level_2_lines)
                if num_level_1_lines > 0 :
                    j_last = 2
                    for i in range(num_level_1_lines):
                        line = level_1_lines[i]
                        if len(line) > 58:
                            loc = line.find('.L0.gz')
                            ##print loc,line
                            if loc > 0 :
                                date_string     = line[0:11]
                                time_string     = line[12:19]
                                time1 = 0
                                time_level_1=find_sec_1970(date_string,time_string)
                                rev = line[48:54]
                                if rev[-1] == '.':
                                    rev = rev[0:5]
                                
                                ## search for the orbit num string in the level 2 list
                                need_to_update_L2a_file = 1  # assume the worst -- either L2A orbit is missing, or older
                                for j in range(j_last,num_level_2_lines):
                                    line2 = level_2_lines[j]
                                    orbit_found = string.find(line2,rev+'.')
                                    date_valid = string.find(line2[0:4],'/')
                                    if ((orbit_found > 0) and (date_valid > 0)):  ## we found the right line
                                        #compare date and time make sure L1B file isn't newer
                                        j_last = j+1
                                        date_string2 = line2[0:11]
                                        time_string2 = line2[12:19]
                                        time_level_2 = find_sec_1970(date_string2,time_string2)
                                        if time_level_1 < time_level_2:
                                            need_to_update_L2a_file = 0  # time is in correct order -- don't need to update             
                                        break
                                    
                                if need_to_update_L2a_file > 0 :
                                    rev = rev+'\n'
                                    revlist_file.write(rev)
                                    if debug > 0:
                                        print 'Need to update ',rev
                                    number_to_update = number_to_update + 1    
                if number_to_update > 0:
                    log_message(str(number_to_update)+' amsu_level 2a files in '+amsu_level_2a_path+' need to be updated',log_ID,1)
                tot_number_to_update = tot_number_to_update + number_to_update
                
            number_file.write(str(tot_number_to_update)+'\n')
            log_message(channel_str+'   '+sat_name+'   '+str(tot_number_to_update),sum_ID,1)
            revlist_file.close
            number_file.close    
            
##@***h* MLT_V4_RSS/find_sec_1970
## NAME
##   MLT_V4_RSS/find_sec_1970
##
## PURPOSE
##   converts date string to time tuple that can be compared (routine is misnamed)
##
## DESCRIPTION
##   converts date string to time tuple that can be compared
##
## INPUTS
##   date_string		string containing date information in month/day/year format
##   time_string		string containing data information in hour/minute/second format
##
## OUTPUTS
##   writes two files.  One contain the number of orbtis to process, and the second contains a list of orbits to process
##
## AUTHOR
##   Carl Mears, Remote Sensing Systems
##
## COPYRIGHT
##   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
##   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
##   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
##   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
##   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
##   THE USE OF THE SOFTWARE AND DOCUMENTATION## OR (2) TO PROVIDE TECHNICAL SUPPORT
##   TO USERS.
##
## HISTORY
##   4/10/2018 Initial Version prepared for NCDC
##
## USAGE
##   time = find_sec_1970(date_string,time_string)
##
##@*****
def find_sec_1970(date_string,time_string):
    year = int(date_string[6:10])
    daymo = int(date_string[3:5])
    month = int(date_string[0:2])
    hour = int(time_string[0:2])
    minute = int(time_string[3:5])
    if time_string[5:6] == 'p':
        hour = hour+12
    time_tuple = year,month,daymo,hour,minute,0,0,0,0
    return calendar.timegm(time_tuple)
    


##@***h* MLT_V4_RSS/process_AMSU_orbits
## NAME
##   MLT_V4_RSS/process_AMSU_orbits
##
## PURPOSE
##   driver program to process incoming AMSU orbits
##
## DESCRIPTION
##   driver program to process incoming AMSU orbits
##
## INPUTS
##   none
##
## OUTPUTS
##   orbitifies and converts L1B to L2a for AMSU data from CLASS.  Both orbitified L1B files and L2a files are written.
##
## AUTHOR
##   Carl Mears, Remote Sensing Systems
##
## COPYRIGHT
##   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
##   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
##   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
##   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
##   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
##   THE USE OF THE SOFTWARE AND DOCUMENTATION## OR (2) TO PROVIDE TECHNICAL SUPPORT
##   TO USERS.
##
## HISTORY
##   4/10/2018 Initial Version prepared for NCDC
##
## USAGE
##   python process_AMSU_orbits.py
##
##@*****

script_name = 'amsu_orbit_processing'
LOG_FILE_PATH = 'm:/MSU_AMSU_Data/AMSU-A_L1A/amsu_orbit_logs/'
SUMMARY_FILE_PATH = 'm:/MSU_AMSU_Data/AMSU-A_L1A/amsu_orbit_summaries/'
time_string = time.strftime("%Y_%m_%d_%H_%M_%S")
date_string = time.strftime("%Y_%m_%d")

log_fyl = LOG_FILE_PATH+script_name+'_'+time_string+'.log'
log_ID = open(log_fyl, 'a')

sat_num_list = ['10','13','14','16','17']
channel_list = ['05','07','09']

log_message('\n',log_ID , 0)
log_message('Starting ' + script_name + '\n',log_ID,1)
log_message('Log File = '+log_fyl+'\n',log_ID,1)

log_message('\n',sum_ID,0)
log_message('Summary File = '+sum_fyl+'\n',sum_ID,1)

strip_number_from_AMSU_L1A_files('NOAA-15')
orbitify_amsu_saa_files(log_ID,'10',log_fyl,sum_ID)  #NOAA-15

strip_number_from_AMSU_L1A_files('NOAA-18')
orbitify_amsu_saa_files(log_ID,'13',log_fyl,sum_ID)  #NOAA-18

strip_number_from_AMSU_L1A_files('NOAA-19')
orbitify_amsu_saa_files(log_ID,'16',log_fyl,sum_ID)  #NOAA-19

strip_number_from_AMSU_L1A_files('METOP-A')
orbitify_amsu_saa_files(log_ID,'14',log_fyl,sum_ID)  #METOP-A

strip_number_from_AMSU_L1A_files('METOP-B')
orbitify_amsu_saa_files(log_ID,'17',log_fyl,sum_ID)  #METOP-B
log_ID = open(log_fyl, 'a')

sat_names = ['NOAA-15','NOAA-18','METOP-A','NOAA-19','METOP-B']
channel_list = ['05','07','09']

start_orbit_list = [90000,55000,50000,35000,20000]
debug = 1

create_amsu_l2a_update_lists(sat_names,channel_list,start_orbit_list,log_ID,sum_ID,debug)

sat_num_list = ['10','13','14','16','17']

for channel_str in channel_list:    
    for sat_num_index in range(0,len(sat_num_list)):
        convert_amsu_l1b_to_l2a(channel_str,sat_num_list[sat_num_index],log_ID,sum_ID)





