!@***m* MLT_V4_RSS/Update_amsu_L2C_monthlies_maps_driver.f90
!  NAME
!    Update_amsu_L2C_monthlies_maps_driver.f90
! 
!  PURPOSE
!    Top level fortran program for assembling AMSU L2A data into monthly maps
! 
!  DESCRIPTION
!   Top level fortran program for assembling AMSU L2A data into monthly maps
!   Satellite number, channel, year, and diurnla model are passed in via command line arguments
!
!  INPUTS
!	satellite number		string from command line argument containing the satellite number
!	channel_str			string from command line argument containing the channel to process
!	year				string from command line argument containing the year to process
!	diurnal_str			string from command line argument containing the diurnal model to use
!
!  OUTPUT
!	monthly maps of AMSU radiance are written to bianry files
!  AUTHOR
!    Carl Mears, Remote Sensing Systems
! 
!  COPYRIGHT
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE COPYRIGHT 2012 REMOTE SENSING SYSTEMS.  
!   THEY ARE PROVIDED FOR INFORMATIONAL AND ALGORITHM VERIFICATION PURPOSES ONLY 
!   AND MAY NOT BE USED IN WHOLE OR IN PART FOR ANY OTHER PURPOSE WITHOUT WRITTEN
!   PERMISSION FROM REMOTE SENSING SYSTEMS.  THEY ARE FURNISHED "AS IS." THE 
!   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
!   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
!   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
!   TO USERS.
! 
!  HISTORY
!    8/15/2012 Initial Version prepared for NCDC
! 
!  USAGE
!    Update_amsu_L2C_monthlies_maps.exe 10 09 2016 CCM3
!
!@*****

	program update_driver

	use date_and_time
	use nan_support
	use AMSU_constants
	use AMSU_L2C_Update_Monthly_Maps_by_FOV
	use AMSU_L2C_Update_Monthly_Maps_TLT
	use DFLIB

	integer(4)				:: sat_num
	integer(4)				:: channel
	integer(4)				:: error
	character(len=20)		:: buffer
	character(len=3)		:: channel_str
	character(len=4)        :: diurnal_str

	integer(4)			:: year
	type(date_Str)		:: first_date_to_process
	type(date_Str)		:: last_date_to_process


	!call init_nan ! no longer needed in new compiler

	buffer = ''
	call getarg(1,buffer,error)
	read(buffer,111)sat_num
	111 format(i3)
	if (error .le. 0) stop
	
	buffer = ''
	call getarg(2,buffer,error)
	channel_str = buffer(1:3)
	if (error .le. 0) stop

	buffer = ''
	call getarg(3,buffer,error)
	read(buffer,112)year
	112 format(i4)
	
	call getarg(4,buffer,error)
	if (error .gt. 0) then
	    read(buffer,113)diurnal_str
	    113 format(a4)
	else
	    diurnal_str = 'CCM3'
	endif

	select case (channel_str)

			case('C01')
				channel  = 1
			case('C02')
				channel  = 2
			case('C03')
				channel  = 3
			case('C04')
				channel  = 4
			case('C05')
				channel  = 5
			case('C06')
				channel  = 6
			case('C07')
				channel  = 7
			case('C08')
				channel  = 8
			case('C09')
				channel  = 9
			case('C10')
				channel = 10
			case('C11')
				channel = 11
			case('C12')
				channel = 12
			case('C13')
				channel = 13
			case('C14')
				channel = 14
			case('C15')
				channel = 15
			case('TLT')
			    channel = 5
			case default
				print *,'Channel Name Does Not Match'
				print *,channel_str
				stop
		endselect

	first_Date_to_process = set_date(1,1,year,error)
	last_Date_to_process = set_date(12,31,year,error)

	if (error .ne. 0) stop
    
	print *, 'Doing Monthly Update for', year,' Channel ',channel_str
	if (channel_str .eq. 'TLT') then
	   call update_AMSU_monthly_maps_TLT(sat_num,channel,first_date_to_process,last_date_to_process,diurnal_str,error)	
	else
	   call update_AMSU_monthly_maps_by_fov_no_adj(sat_num,channel,first_date_to_process,last_date_to_process,error)	
	endif
end program	update_driver 