;@***h* MLT_V4_RSS/calc_adjustments_amsu_fov_main.pro
; NAME
;   MLT_V4_RSS/calc_adjustments_amsu_fov_main.pro
;
; PURPOSE
;   top level program that calculates angle and diurnal adjustment for AMSU
;
; DESCRIPTION
;   top level program that calculates angle and diurnal adjustment for AMSU
;   
; INPUTS
;   none
;
; OUTPUTS
;   writes diurnal and angle adjustment gridded monthly files
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   4/10/2018 Initial Version prepared for NCDC
;
; USAGE
;   .r calc_adjustments_amsu_fov_main
;
;@*****

load_AMSU_file_locations,verbose=1

; define commom blocks
; EIA common block -- contains info need for the angle adjustments

common eia, eia__adj_arr, eia__channel_loaded,eia__model_loaded,eia__lat_map, $
       eia__cross_track_offsets,eia__cross_track_sat_loaded,eia__cross_track_channel_loaded, $
       AMSU_VIEW_ANGLES,AMSU_NOM_EIAS

eia__channel_loaded = -1
eia__cross_track_sat_loaded = -1
eia__cross_track_channel_loaded = -1
eia__cross_track_offsets = fltarr(30)
eia__model_loaded = 'none'

AMSU_VIEW_ANGLES = [1.6666666,5.0000000,8.3333333,11.666667,15.000000,  $
                    18.333333,21.666667,25.000000,28.333333,31.666667,  $
                    35.000000,38.333333,41.666667,45.000000,48.333333]

AMSU_NOM_EIAS    = [1.875947, 5.629541, 9.388301,13.155880,16.936250,   $
                    20.733890,24.554020,28.402830,32.287970,36.219100,  $
                    40.208800,44.274040,48.438570,52.737200,57.224260]
                    
; END EIA common block

; Diurnal common block

common diurnal, diur__adj_arr, diur__channel_loaded,diur__model_loaded,diur__lat_time_map
  diur__channel_loaded = -1
  diur__model_loaded  = 'none'
  
; END Diurnal Common Block

; Satellites Common Block

common satellites, satellites__num_sats,satellites__num_months
start_year = 1998
end_year   = 2018
satellites__num_sats = 8
satellites__num_months = 12*(1+end_year-start_year)

; END Satellites Common Block
                    
for channel = 7,7 do begin
  if channel eq 6 then continue
  if channel eq 8 then continue
  channel_str = string(channel,format = '("C",i2.2)')
  fov_wts = fltarr(30)
  ;fov_wts[9:20] = 1.0 & fov_str = 'N12'
  fov_wts[4:25] = 1.0 & fov_str = 'N22'
  
  if channel eq 9 then begin
    fov_wts = fltarr(30)
    fov_wts[6:9] = 1.0
    fov_wts[20:23] = 1.0
    fov_str = 'L8'
  endif
  node_wts = [1.0,1.0]
  adj_flag = 7
  sats_to_use =  [1,1,0,1,1,1,1,1]
  ;sats_to_use =  [0,0,0,0,1,0,0,0]
  
  num_sats = n_elements(sats_to_use)
  
  angle_model = 'MERRA'
  diurnal_model_list = ['MERRA','CCM3','HADGEM']
  for diur_index = 0,2 do begin
    diurnal_model = diurnal_model_list[diur_index]
    for year_to_process = start_year,end_year do begin
      calc_and_save_all_AMSU_adjustments_from_FOV,  $
          channel,              $
          fov_wts,              $
          fov_str,              $
          node_wts,             $
          adj_flag,             $
          tb_arr_adj,           $
          tar_arr=tar_arr,      $
          num_arr=num_arr,      $
          sats_to_use = sats_to_use,    $
          angle_model = angle_model,    $
          diurnal_model = diurnal_model,$
          year_to_process = year_to_process
     endfor
   endfor
endfor

end
