

;@***h* MLT_V4_RSS/calc_amsu_diurnal_adjustments.pro
; NAME
;   MLT_V4_RSS/calc_amsu_diurnal_adjustments.pro
;
; PURPOSE
;   calculates maps of diurnal adjustments for AMSU
;
; DESCRIPTION
;   calculates maps of diurnal adjustments for AMSU.  The diurnal cycles are contained in the "Diurnal" common block
;   measurement times are found in this routine.
;
; INPUTS
;   satnum              integer: satellite number (1..9)
;   year                integer: year to process
;   month               integer: month of year to process
;
; OUTPUTS
;  diurnal_adjustment       array of reals [2,30,144,72]:  adjustments to nominal meausrement time
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   4/10/2018 Initial Version prepared for NCEI
;
; USAGE
;   calc_msu_diurnal_adjustments,satnum,year,month,diurnal_adjustment
;
;@*****

pro calc_amsu_diurnal_adjustments,satnum,year,month,diurnal_adjustment

  forward_function get_nth_value
  common diurnal

   calc_amsu_measurement_times,satnum,year,month,measurement_times
   ok = where(finite(measurement_times) eq 1,ct)
   diurnal_adjustment = replicate(!values.f_nan,2,30,144,72)
   if ct gt 100000L then begin   
     for node = 0,1 do begin
       for fov = 0,29 do begin
          diur_maps = reform(diur__adj_arr[month-1,floor(abs(fov-14.5)),*,*,*])
          meas_hours = -0.5 + measurement_times[*,*,fov,node]/3600.0
          bad = where(finite(meas_hours) eq 0,bad_ct)
          hour_lower = floor(meas_hours)
          too_low = where(hour_lower lt 0,too_low_ct)
          if too_low_ct gt 0 then begin
            hour_lower[too_low] = hour_lower[too_low]+ 24
          endif

          hour_upper = hour_lower + 1
          too_high = where(hour_upper gt 23,too_high_ct)
          if too_high_ct gt 0 then begin
            hour_upper[too_high] = hour_upper[too_high]- 24
          endif

          wt_upper = meas_hours-hour_lower
          wt_lower = 1.0 - wt_upper
          if bad_ct gt 0 then hour_lower[bad] = 0
          if bad_ct gt 0 then hour_upper[bad] = 0
          tb_lower = get_nth_value(diur_maps,hour_lower)
          tb_upper = get_nth_value(diur_maps,hour_upper)
          diur_tb_meas_time = tb_lower*wt_lower + tb_upper*wt_upper
          diur_tb_midnight = (diur_maps[*,*,0]+diur_maps[*,*,23])*0.5
          diur_tb_noon = (diur_maps[*,*,11]+diur_maps[*,*,12])*0.5
          ;diurnal_adjustment[node,fov,*,*] = diur_tb_noon-diur_tb_meas_time
          diurnal_adjustment[node,fov,*,*] = 0.0-diur_tb_meas_time  ;This change was made nov 13,2014
                                                                    ; all diurnal files should be from after this time
          
       endfor
     endfor
   endif




end
