;@***h* MLT_V4_RSS/calc_amsu_measurement_times.pro
; NAME
;   MLT_V4_RSS/calc_amsu_measurement_times.pro
;
; PURPOSE
;   reads maps of MSU local measurement time for a given satellite, year and month
;
; DESCRIPTION
;   reads maps of MSU local measurement time for a given satellite, year and month
;   there are difference maps for each FOV because of the difference in local time across
;   each swath
;
; INPUTS
;   satnum              integer: satellite number (1..9)
;   year                integer: year to process
;   month               integer: month of year to process
;
; OUTPUTS
;  measurement_times      array of reals [144,72,30,2]:  local measurement time
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   4/10/2018 Initial Version prepared for NCEI
;
; USAGE
;   calc_amsu_measurement_times,satnum,year,month, measurement_times
;
;@*****

pro calc_amsu_measurement_times,satnum,year,month,measurement_times   ; measurement times is 144 x 72 x 15 array of local times

    restore,'M:\MSU_AMSU_data\AMSU_Navigation\AMSU_crossing_times.sav'

    restore,'M:\MSU_AMSU_data\AMSU_Adjustments\AMSU_Diurnal\Measurement_Times\AMSU_meas_time_offset.sav'
    imonth = 12*(year-1978) + month - 1
    secs_in_day = 3600.0*24.0
    xtime = AMSU_MONTHLY_XTIME_ARRAY(satnum-10,imonth)
    meas_times2 = (meas_time_offset_72 + xtime + 2.0*secs_in_day) mod secs_in_day
        
    measurement_times = fltarr(144,72,30,2)
    for ilon = 0,143 do begin
       measurement_times[ilon,*,*,*] = meas_times2
    endfor
 end