;@***h* MLT_V4_RSS/read_diurnal_adj_arr.pro
; NAME
;   MLT_V4_RSS/read_diurnal_adj_arr.pro
;
; PURPOSE
;   reads amsu diurnal adjustment arrays
;
; DESCRIPTION
;   reads amsu diurnal adjustment arrays
;
; INPUTS
;   channel   integer, AMSU channel number
;   model     string containing name of diurnal adjustment model ('CCM3','MERRA','HADGEM')
;   month     integer, 1..12, month number
;
; OUTPUTS
;   diur_tbs  array of reals [12,15,144,72,24] of diurnal adjustment parameters.
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   4/10/2018 Initial Version prepared for NCDC
;
; USAGE
;   read_diurnal_adj_arr,5,'CCM3',diur_Tbs,err
;
;@****

pro read_diurnal_adj_arr,channel,model,diur_tbs,err
  err = -1

  case model of
    'HADGEM': begin
      diur_file = string(!AMSU_ADJUSTMENT_PATH,model,channel,model, $
        format = '(a,"AMSU_Diurnal\",a,"_Diurnal_Climatology\mn_diur_cycles_AMSU_chan_",i2.2,"_",a,"_144x72_saane.dat")')
      end
    'CCM3': begin
      diur_file = string(!AMSU_ADJUSTMENT_PATH,model,channel, $
        format = '(a,"AMSU_Diurnal\",a,"_Diurnal_Climatology\mn_CCM3_diur_cycles_AMSU_chan_",i2.2,".dat")')
      end
    else: begin
      diur_file = string(!AMSU_ADJUSTMENT_PATH,model,channel,model, $
        format = '(a,"AMSU_Diurnal\",a,"_Diurnal_Climatology\mn_diur_cycles_AMSU_chan_",i2.2,"_",a,"_144x72.dat")')
      end
  endcase
  ;endif else begin
  ;  diur_file = string(!AMSU_ADJUSTMENT_PATH,model,channel,model, $
  ;    format = '(a,"AMSU_Diurnal\",a,"_Diurnal_Climatology\mn_diur_cycles_AMSU_chan_",i2.2,"_",a,"_144x72_saane.dat")')
  ;endelse
  diur_tbs = fltarr(12,15,144,72,24)
  close,3
  print,'Reading ',diur_file
  openr,3,diur_file
  mat = fltarr(144,72)
  for fov = 0,14 do begin
    for month = 0,11 do begin
      for hour = 0, 23 do begin       
        ; 14-fov reverses order so that fov = 1 is the nader position 
        readu,3, mat
        diur_tbs[month,14-fov,*,*,hour] = mat
      endfor
    endfor
  endfor 
  err = 0
  end