;@***h* MLT_V4_RSS/write_amsu_diurnal_adjustment_fov.pro
; NAME
;   MLT_V4_RSS/write_amsu_diurnal_adjustment_fov.pro
;
; PURPOSE
;   writes AMSU diurnal adjustment maps
;   
; DESCRIPTION
;   writes AMSU diurnal adjustment maps
;
; INPUTS
;   satnum                  integer: satellite number (1..9)
;   channel                 integer:  AMSU channel number
;   year                    integer: year to process
;   month                   integer: month to process
;  diurnal_model            string:  name of diurnla model used
;  diurnal_adjustment       array of reals [2,30,144,72]: diurnal adjustment maps to save
;
; OUTPUTS
;  none
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   4/10/2018 Initial Version prepared for NCEI
;
; USAGE
;    write_amsu_diurnal_adjustment_fov,satnum,channel,year,month,diurnal_model,diurnal_adjustment,error
;
;@*****

pro write_amsu_diurnal_adjustment_fov,satnum,channel,year,month,diurnal_model,diurnal_adjustment,error

  if ((satnum lt 10) or (satnum gt 17)) then begin
    print,'Satnum '+string(satnum)+' is not an AMSU instrument'
    err = -1
    return
  endif
  name = sat_name(satnum)
  ; example path: U:\AMSU-A_L2C\Monthly_Maps\AMSU_Channel_10\fov_maps\noaa-15\y1998_m08_fov_hist_144_72_v3_02.dat'
  path = string(channel,name,format='("m:\MSU_AMSU_data\AMSU-A_L2C\Monthly_Maps_V4\AMSU_Channel_",i2.2,"\fov_maps\",a,"\diurnal_adjustment\")')
  info = file_info(path)
  if info.exists eq 0 then begin
    file_mkdir,path
  endif
  file = path + string(year,month,diurnal_model,format = '("y",i4.4,"_m",i2.2,"_fov_hist_144_72_v4_01.",a,".dat")')
  close,3
  openw,3,file
  writeu,3,month,year,channel
  pad = '                '
  len = strlen(diurnal_model)
  diurnal_model_pad = diurnal_model + strmid(pad,0,16-len)
  writeu,3,diurnal_model_pad
  writeu,3,diurnal_adjustment
  close,3
end
