;@***h* MLT_V4_RSS/amsu_v4_grpt_merge_refactor.tlt_op.pro
; NAME
;   amsu_v4_grpt_merge_refactor.tlt_op.pro
;
; PURPOSE
;   top level program that performs TLT merge for AMSU
;
; DESCRIPTION
;   top level program that performs TLT merge for AMSU.  The merging process is described in 
;
;   Mears, C. A., & Wentz, F. J. (2016). Sensitivity of Satellite-Derived Tropospheric Temperature
;   Trends to the Diurnal Cycle Adjustment. Journal of Climate, 29, 3629-3646. doi: 10.1175/JCLI-D-15-0744.1
;
;   The program defines several common block, then read in data and performs simple QC analysis to 
;   remove data that is too sparse for a given month/satellite.  The program then calculates the various merging parameters.
;   They are:
;     Target Factors
;     Adjustments to the diurnal correction
;     Intersatellite offsets
;   
;   The merged data product is then written.
; INPUTS
;   input variables
; OUTPUTS
;   output variable and descriptions
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   1/10/2018 Initial Version prepared for NCDC
;
; USAGE
;   .r amsu_v4_grpt_merge_refactor.tlt_op.pro
;
;@*****

version_num = 0
start_year = 1998
end_year = 2018
report_path = 'E:\MSU_AMSU\IDL_MSU_AMSU_V4\Merge_Monthly_AMSU_FOV_V4\TLT_reports_op\'
log_path    = 'E:\MSU_AMSU\IDL_MSU_AMSU_V4\Merge_Monthly_AMSU_FOV_V4\TLT_logs_op\'
output_path = 'E:\MSU_AMSU\IDL_MSU_AMSU_V4\Merge_Monthly_AMSU_FOV_V4\TLT_results_op\'
ok = check_path(report_path,/create)
ok = check_path(log_path,/create)
ok = check_path(output_path,/create)
channel_str = 'TLT'
defsysv,'!log_lun',2
log_file = string(log_path,channel_str,version_num,format='(a,"merge_log_fov_amsu_channel_",a,"_v4.",i5.5,".log.txt")')
close,!log_lun
openw,!log_lun,log_file
reread_data =1
amsu_channel = 5

load_AMSU_file_locations,verbose=1
read_land_fraction_144_72,lf
land_mask = intarr(144,72)
land = where(lf gt 0.5)
land_mask[land] = 1.0


num_months = 12*(1 + end_year - start_year)
num_sats = 8

AMSU_VIEW_ANGLES = [1.6666666,5.0000000,8.3333333,11.666667,15.000000,  $
                    18.333333,21.666667,25.000000,28.333333,31.666667,  $
                    35.000000,38.333333,41.666667,45.000000,48.333333]

AMSU_NOM_EIAS    = [1.875947, 5.629541, 9.388301,13.155880,16.936250,   $
                    20.733890,24.554020,28.402830,32.287970,36.219100,  $
                    40.208800,44.274040,48.438570,52.737200,57.224260]



num_thres = 200
adj_flag = 5  ; Should be 5 to perform height adjustment!

diurnal_models = ['no_adj','CCM3','HADGEM','MERRA','CMAM','no_adj','CCM3','HADGEM','MERRA','CMAM']
diurnal_dict =  DICTIONARY("no_adj","none", "CCM3","ccm3","HADGEM","hgs1","MERRA","merr")

offset_scheme = 'land_ocean_separate'
offset_scheme_index = 2


tf_scheme = 'ocean_only'
tf_surf = 'Sea'
tf_scheme_index = 2

  
  
sats_to_use = [1,0,0,1,1,1,1,1]
 ; months_to_use_mask = intarr(num_months,num_sats)
  
  
diurnal_index = 6
months_to_use_mask = intarr(num_months,num_sats)

use_seasonal_diurnal_fit = 1
if (diurnal_index lt 5) then use_seasonal_diurnal_fit = 0
diurnal_model = diurnal_models[diurnal_index]
diurnal_model_for_tlt_read = diurnal_dict[diurnal_model]
diurnal_factor = 1.0
perform_diurnal_adjustment = 0
if diurnal_index ge 5 then perform_diurnal_adjustment = 1         
reread_data = 1
if reread_data then begin
     read_all_adjusted_AMSU_maps_TLT, amsu_channel,       $
                                       node_wts,           $
                                       adj_flag,           $
                                       tb_arr,         $
                                       tar_arr=tar_arr,    $
                                       num_arr=num_arr,    $
                                       sats_to_use = sats_to_use,     $
                                       months_to_use_mask = months_to_use_mask, $
                                       diurnal_model = diurnal_model_for_tlt_read, $
                                       diurnal_factor = diurnal_factor, $
                                       /do_TLT_adjustment,  $
                                       tb_arr_raw = tb_arr_raw  ;,          $
                                              ;eia_model = eia_model;, $
                                              ;tb_arr_raw = tb_arr_raw

     tb_arr_save = tb_arr
endif else begin
     tb_arr = tb_arr_save
endelse
tb_arr_adj = tb_arr
              
sats_to_use_schemes = [ 'all_aqua_n15_trunc']        

sats_to_use_index = 5L
months_to_use_mask[144:num_months-1,5] = -1  ; truncate AQUA after 2009
months_to_use_mask[168:num_months-1,0] = -1  ; truncate NOAA-15 after 2011
months_to_use_mask[0:131,3] = -1             ; truncate NOAA-18 before 2009

months_to_use_mask[161,4] = 1
months_to_use_mask[162,4] = 1
months_to_use_mask[163,4] = 1
sats_to_use = [1,0,0,1,1,1,1,1]


 log,'Info: AMSU Only V 4 log file"
 log,'Info:','Channel = ',channel_str
 log,'Info:','Diurnal model =',diurnal_model
 log,'Info:','EIA_model = ',eia_model
 log,'Info:','Version Num = 4.'+string(version_num,format = '(i5.5)')
 sats_used_str = ''
 for satnum = 0,num_sats - 1 do begin
   if sats_to_use[satnum] gt 0 then sats_used_str = sats_used_str + sat_name(satnum + 10)+' '
 endfor
 log,'Info:','Satellites Used: ',sats_used_Str
       
 ; calculate the target factors
 calc_TF_from_grpt_maps_AMSU_v4,tb_arr_adj,tar_arr,num_arr,channel_str,sats_to_use,target_factor,target_means,offset,months_to_use, $
    num_thres=num_thres,months_to_use_mask=months_to_use_mask,tf_surf=tf_Surf


 not_used = where(sats_to_use lt 1,ct)
 if ct gt 0 then target_factor[not_used] = !values.f_nan
 if ct gt 0 then target_means[not_used] = !values.f_nan
 if ct gt 0 then offset[not_used] = !values.f_nan
 log,'Info: Target Factors =',target_factor
 log,'Info: Target Means   =',target_means
 log,'Info: Mean Offsets   =',offset

      
 log,'Info: Applying Target Factors'
 apply_TF_to_grpt_maps_AMSU_v4,tb_arr_adj,tar_arr,channel,target_factor,target_means,months_to_use,tb_arr_adj2



       
 ; In in this section, the diurnal adjustment is optimized using an additional
 ; second harmonic adjustment.
 ; This adjustment can either be seasonally modulated or not.  This doesn't
 ; make much difference for the overall results, but the intersatellite differences
 ; are better near the poles with the seasonal modulation
       
if perform_diurnal_adjustment ge 1 then begin
   if use_seasonal_diurnal_fit then begin
      diurnal_residual_parameters = fltarr(14,2,72)
   endif else begin
      diurnal_residual_parameters = fltarr(10,2,72)
   endelse
   t = findgen(120)/10.0

   for month = 0,203 do begin
     for satnum = 0,7 do begin
       if months_to_use[month,satnum] lt 1 then tb_arr_adj2[*,*,month,satnum] = !values.f_nan
     endfor
   endfor
 
   if use_seasonal_diurnal_fit then begin
     log,'Info: Optimizing Diurnal Adjustment with seasonally modulated second harmonic'
   endif else begin
     log,'Info: Optimizing Diurnal Adjustment with seasonally constant second harmonic'
   endelse
 
   for ilat = 0,71 do begin
      lat_range = [-90.0 + 2.5*(ilat-2),-90.0 + 2.5*(ilat+3)]     
      ;lat_range = [-90.0 + 2.5*(ilat),-90.0 + 2.5*(ilat+1)]
      
      ; find corrections to diurnal adjustment 
      if use_seasonal_diurnal_fit then begin
        fit_residual_diurnal_w_seasonal,tb_arr_adj2,lat_range,params
      endif else begin
        fit_residual_diurnal,tb_arr_adj2,lat_range,params
      endelse
      
      ; assign sea and land params the land_sea values for ilat = 0..17
      if ilat le 17 then begin
        params[*,0] = params[*,2]
        params[*,1] = params[*,2]
      endif
      diurnal_residual_parameters[*,*,ilat] = params[*,0:1]
   endfor
   
   save_file = string(report_path,channel_str,version_num,format='(a,"diurnal_residual_parameters_chan_",a,"_v",i5.5,".sav")')
   save,file=save_file,diurnal_residual_parameters
 
   diurnal_residual_parameters[0:7,*,*] = 0.0  ; zero the offsets for this step!  They'll be fixed later in calc_offsets_from_grpt_maps_AMSU_v4
   log,'Info: Applying Diurnal Adjustments'
   apply_diurnal_fit_residuals,tb_arr_adj2,diurnal_residual_parameters,tb_arr_adj2
endif ; perform diurnal adjustment


file = string(report_path,channel_str,version_num,format = '(a,"merge_report_fov_amsu_channel_",a,"_v4.",i8.8,".ps")')
set_up_ps,file=file,xsize=7.5,ysize=10.0
log,'Info: merge_report_file =',file
  
; calculate offsets, with separate offsets for land and ocean parts of each zonal band.

calc_offsets_from_grpt_maps_AMSU_v4_land_ocean_sep,tb_arr_adj2,months_to_use,offsets
adjust_offsets_by_land_fraction,offsets,offsets_adj
offsets_adj_sm = offsets_adj
smooth_offsets,offsets_adj[*,*,0],temp
offsets_adj_sm[*,*,0] = temp
smooth_offsets,offsets_adj[*,*,1],temp
offsets_adj_sm[*,*,1] = temp
plot_offsets,offsets,offsets2=offsets_adj_sm
tb_arr_adj3 = tb_arr_adj2
apply_offsets_to_grpt_maps_AMSU_v4_land_ocean_sep,tb_arr_adj3,offsets_adj_sm

; make merge evaluation plots....
sat_pairs = [[0,5],[3,5],[4,5],[0,4],[3,4],[6,4],[7,4],[0,3]]
eval_grpt_merge_global_amsu,  tb_arr_adj3,                      $
                                    num_arr,                    $
                                    months_to_use,              $
                                    raw_Tbs = tb_arr,          $
                                    mean_rms = mean_rms,        $
                                    mean_Stddev = mean_stddev,  $
                                    stddev_diff = stddev_diff,  $
                                    mean_diffs = mean_diffs,    $
                                    channel_Str = channel_str,  $
                                    version_num = version_num,  $
                                    sat_pairs = sat_pairs,      $
                                    plot_path = report_path


eval_grpt_merge_hoffmuller_v4_AMSU,tb_arr_adj3,num_arr,months_to_use

     
; perform the merge
merge_tb_maps_AMSU_v4,tb_arr_adj3,num_arr,tb_arr_merged,months_used = months_used,num_thres = 4
; expand merge coefficients to maps for metadata
offset_arr = replicate(!values.f_nan,144,72,num_sats)
tarmult_arr = replicate(!values.f_nan,144,72,num_sats)
tbmult_arr = fltarr(144,72,num_sats)
        
;need to fix this eventually - -just expanding offsets for metadata.
for sat = 0,num_sats-1 do begin
  tarmult_arr[*,*,sat] = target_factor[sat]
endfor
        
 sz_offsets = size(offsets,/dimensions)
        
if n_elements(sz_offsets) eq 2 then begin   
  for ilon = 0,143 do begin
    offset_arr[ilon,*,*] = offsets
  endfor
endif else begin  ; sz offsets should be [72,9,2]  
  bad = where(finite(offsets[*,*,1]) eq 0,ct)
  if ct gt 0 then begin
    temp1 = offsets[*,*,1]
    temp2 = offsets[*,*,0]
    temp1[bad] = temp2[bad]
    offsets[*,*,1] = temp1
  endif
  for sat = 0,num_sats-1 do begin
    for ilat = 0,71 do begin
      offset_arr[*,ilat,sat] = offsets[ilat,sat,0]*(1.0-lf[*,ilat]) + offsets[ilat,sat,1]*lf[*,ilat]
    endfor
  endfor
endelse

; more evaluation plots
channel = 'TLT'
compare_new_merged_amsu_to_baseline,tb_arr_merged,target_factor,months_to_use,version_num,channel=channel
       
; write the output file
 tlt_wts = [-2.64,-1.14,0.44,1.41,1.61,1.17,0.40,-0.25,0.0,0.0,0.0,0.0,0.0,0.0,0.0]
 fov_wts = [tlt_wts,reverse(tlt_wts)]
  write_amsu_only_merged_Tbs_144_72_netcdf_4_0,       $
                Tbs_144_72 = tb_arr_merged ,          $
                channel_str=channel_str,              $
                version_num=version_num,              $
                diurnal_model = diurnal_model,   $
                eia_model = 'NCEP',        $
                fov_wts = fov_wts,                    $
                node_wts = node_wts,                  $
                adjustment_flag = adj_flag,           $
                offsets = offset_arr,                 $  ;[144,72,num_sats]
                target_factors = tarmult_arr,         $  ;[144,72,num_sats]
                tb_Factors = tbmult_arr,              $  ;[144,72,num_sats]
                target_means = target_means,          $  ;[num_sats]
                months_used = months_used,            $  ;[num_months,num_sats]
                output_path = output_path
                
  log,'Info: Normal End'
  close,!log_lun
  print
  device,/close
  set_win

end
