pro apply_TF_to_grpt_maps_AMSU_v4,tb_arr,tar_arr,channel,target_factors,target_means,months_to_use,tb_arr_adj
  ;@***h* MLT_V4_RSS/apply_TF_to_grpt_maps_AMSU_v4
  ; NAME
  ;   apply_TF_to_grpt_maps_AMSU_v4
  ;
  ; PURPOSE
  ;   applies target factor adjustments to antenna temperature gridded maps
  ;
  ; DESCRIPTION
  ;   applies target factor adjustments to antenna temperature gridded maps.  The target factors are specified in the
  ;   calling statement.  
  ;
  ; INPUTS
  ;   tb_arr                fltarr array (144 x 72 x num_months x num_sats) of adjusted antenna temperatures
  ;   tar_arr               fltarr array (144 x 72 x num_months x num_sats) of calibration target temperatures
  ;   channel               AMSU channel code - should be a 3 character channel string (TLT,TMT, etc)
  ;   target_factor         values of computed target factors
  ;   target_means          mean values of target temperatures
  ;   months_to_use         intarr(num_sats x num_months) of months to use in subsequent processing.
  ;
  ; OUTPUTS
  ;   tb_arr_adj            fltarr array (144 x 72 x num_months x num_sats) of antenna temperatures with target temperature 
  ;                         adjustments applied.
  ;
  ; AUTHOR
  ;   Carl Mears, Remote Sensing Systems
  ;
  ; COPYRIGHT
  ;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
  ;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
  ;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
  ;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
  ;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
  ;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
  ;   TO USERS.
  ;
  ; HISTORY
  ;   1/10/2018 Initial Version prepared for NCDC
  ;
  ; USAGE
  ;   apply_TF_to_grpt_maps_AMSU_v4,tb_arr_adj,tar_arr,channel,target_factor,target_means,months_to_use,tb_arr_adj2
  ;
  ;@*****
  
	sz = size(tb_arr,/dimensions)
	num_months = sz[2]
	num_sats = sz[3]

	tb_arr_adj = tb_arr/0.0
	for month = 0,num_months-1 do begin
		for satnum = 0,num_sats-1 do begin
			if months_to_use[month,satnum] lt 1 then continue
			tb_arr_adj[*,*,month,satnum] = tb_arr[*,*,month,satnum] - target_factors[satnum]*(tar_arr[*,*,month,satnum]-target_means[satnum])
		endfor
	endfor
end
