pro merge_tb_maps_AMSU_v4,tb_arr,num_arr,tb_arr_merged,months_used = months_used,num_thres = num_thres

;@***h* MLT_V4_RSS/merge_tb_maps_AMSU_v4
; NAME
;   merge_tb_maps_AMSU_v4
;
; PURPOSE
;   Merges maps from disparate AMSU satellite together using simple averaging.
;
; DESCRIPTION
;   Merges maps from disparate AMSU satellite together using simple averaging.  The months/locations to be included in the merge 
;   founnd by compaing the number of observations in each grid cell with a number threshold
;
;   The operates directly on the adjusted tb maps
; INPUTS
;   tb_arr      fltarr array (144 x 72 x num_months x num_sats) of adjusted antenna temperatures
;   num_arr     fltarr array (144 x 72 x num_months x num_sats) of number of obs in each grid cell
;   num_thres   integer threshold number of obs for accepting a grid cell
;    
; OUTPUTS
;   tb_arr_merged  fltarr array (144 x 72 x num_months) of merged antenna temperatures
;   months_used    intarr array (num_months x num_sats) of satellite months used (1= used, 0 = not used) 
;   
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   1/10/2018 Initial Version prepared for NCDC
;
; USAGE
;   merge_tb_maps_AMSU_v4,tb_arr_adj3,num_arr,tb_arr_merged,months_used = months_used,num_thres = 4
;
;@*****
    if keyword_set(num_thres) eq 0 then num_thres = 4
    sz = size(tb_arr,/dimensions)
    num_lons = sz[0]
    num_lats = sz[1]
    num_months = sz[2]
    num_sats = sz[3]
    
    tb_arr_merged = replicate(!values.f_nan,num_lons,num_lats,num_months)
    log,'Merging'
    
    months_used = intarr(num_months,num_sats)
    for i = 0,num_months-1 do begin
      tot_tb = fltarr(num_lons,num_lats)
      tot_num = fltarr(num_lons,num_lats)
      for satnum = 0,num_sats-1 do begin
        tb = tb_arr[*,*,i,satnum]
        num = num_arr[*,*,i,satnum]
        ok = where((finite(tb) gt 0) and (num gt num_thres),ct)
        if ct gt 100 then begin
          tot_tb[ok] = tot_tb[ok] + tb[ok]
          tot_num[ok] = tot_num[ok] + 1
          months_used[i,satnum] = 1
        endif
      endfor ; satnum
      tb_merged = tot_tb/tot_num
      tb_arr_merged[*,*,i] = tb_merged
    endfor
 end