pro read_amsu_incidence_adjustment_fov,satnum,channel,year,month,eia_model,incidence_adjustment,error

  ;@***h* MLT_V4_RSS/read_amsu_incidence_adjustment_fov
  ; NAME
  ;   read_amsu_incidence_adjustment_fov
  ;
  ; PURPOSE
  ;   read incidence adjustment to be applied to a given monthly antenna temperature gridded dataset
  ;
  ; DESCRIPTION
  ;   read incidence adjustment to be applied to a given monthly antenna temperature gridded dataset.  The satellite
  ;   number, channel, year, month, and incidence model name are specified by the calling statement
  ;
  ;   The operates directly on the adjusted tb maps
  ; INPUTS
  ;   satnum          integer satellite number (NOAA-15 = 10, etc
  ;   channel         integer AMSU channel number
  ;   year            integer year of file to be loaded
  ;   month           integer month of file to be loaded
  ;   eia_model       string  name of incidence model (probably "NCEP")
  ; OUTPUTS
  ;   incidence adjustment  fltarr(2,30,144,72) array of incidence adjustments
  ;   error               integer error flag
  ;
  ; AUTHOR
  ;   Carl Mears, Remote Sensing Systems
  ;
  ; COPYRIGHT
  ;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
  ;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
  ;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
  ;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
  ;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
  ;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
  ;   TO USERS.
  ;
  ; HISTORY
  ;   1/10/2018 Initial Version prepared for NCDC
  ;
  ; USAGE
  ;   read_amsu_incidence_adjustment_fov,satnum,channel,year,month,eia_model,diurnal_adjustment,diur_error
  ;
  ;@*****
  if ((satnum lt 10) or (satnum gt 17)) then begin
    log,'Satnum '+string(satnum)+' is not an AMSU instrument'
    err = -1
    return
  endif
  name = sat_name(satnum)
  ; example path: U:\AMSU-A_L2C\Monthly_Maps\AMSU_Channel_10\fov_maps\noaa-15\y1998_m08_fov_hist_144_72_v3_02.dat'
  path = string(channel,name,format='("M:\MSU_AMSU_Data\AMSU-A_L2C\Monthly_Maps_V4\AMSU_Channel_",i2.2,"\fov_maps\",a,"\incidence_adjustment\")')
  file = path + string(year,month,eia_model,format = '("y",i4.4,"_m",i2.2,"_fov_hist_144_72_v4_01.",a,".dat")')
  info = file_info(file)
  if info.exists eq 1 then begin
    close,3
    openr,3,file
    log,'Info: Incidence file = ',file,/quiet
    monthx = 0
    yearx = 0
    channelx = 0
    readu,3,monthx,yearx,channelx
    eia_modelx = '                '
    readu,3,eia_modelx
    incidence_adjustment = fltarr(2, 30, 144, 72)
    readu,3,incidence_adjustment
    close,3
  endif else begin
    error = -1
    incidence_adjustment = replicate(!values.f_nan,2,30,144,72)
  endelse
end
