;@***h* MLT_V4_RSS/read_AMSU_monthly_map_by_fov
; NAME
;   read_AMSU_monthly_map_by_fov
;
; PURPOSE
;   reads a single AMSU antenna temperature file
;
; DESCRIPTION
;   reads a single AMSU antenna temperature file for a given satellite number, year, and month.
;
; INPUTS
;   satnum      satellite number, NOAA-15 = 15, etc
;   channel     amsu channel number (5, 7 or 9)
;   year        year of the file to be read
;   month       month (1..12) of the file to be read
;
; OUTPUTS
;   tb_arr      fltarr(4,2,30,144,72) antenna temperature data
;   err         integer error flag
;   tb_hist     (optional) histogram of antenna temperature values.
;   tb_range    (optional) range of antenna temperatures found in the file
;
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   1/10/2018 Initial Version prepared for NCDC
;
; USAGE
;   read_AMSU_monthly_map_by_fov,satnum,channel,year,month,tb_arr,err
;
;@*****

pro read_AMSU_monthly_map_by_fov,satnum,channel,year,month,tb_arr,err,tb_hist=tb_hist,tb_range=tb_range


  
  if ((satnum lt 10) or (satnum gt 17)) then begin
    print,'Satnum '+string(satnum)+' is not an AMSU instrument'
    err = -1
    return
  endif
  name = sat_name(satnum)
  ; example path: M:\MSU_AMSU_Data\AMSU-A_L2C\Monthly_Maps\AMSU_Channel_10\fov_maps\noaa-15\y1998_m08_fov_hist_144_72_v3_02.dat'
  file = string(channel,name,year,month,format='("M:\MSU_AMSU_Data\AMSU-A_L2C\Monthly_Maps_v4\AMSU_Channel_",i2.2,"\fov_maps\",a,"\tb_no_adj\y",i4.4,"_m",i2.2,"_fov_hist_144_72_v4_01.dat")')
  
  close,3
  info = file_info(file)
  if info.exists gt 0 then begin
    openr,3,file
    log,'Info: Tb file =',file,/quiet
    month2 = 0L
    year2 = 0L
    channel2 = 0L
    tb_arr = fltarr(4,2,30,144,72)
    readu,3,month2,year2,channel2,tb_arr
    if info.size gt 10013291L then begin
      tb_hist = fltarr(500,30)
      readu,3,tb_hist
    endif else begin
      tb_hist = replicate(!values.f_nan,500,30)
    endelse
  endif else begin
    tb_arr = replicate(!values.f_nan,4,2,30,144,72)
    tb_hist = replicate(!values.f_nan,500,30)
    err = -1
    return
  endelse
  
  close,3
  err = 0
  return
  
  io_error:
    err = -1
    tb_arr = replicate(!values.f_nan,4,2,30,144,72)
end