pro write_amsu_only_merged_Tbs_144_72_netcdf_4_0,	Tbs_144_72 = Tbs_144_72 ,		$
													channel_str=channel_str,		           $
													version_num=version_num,		           $
													diurnal_model = diurnal_model,    $
                          eia_model = eia_model,         $
                          fov_wts = fov_wts,                     $
                          node_wts = node_wts,                   $
                          adjustment_flag = adjustment_flag,            $        
													offsets = offsets,				             $
													target_factors = target_factors,       $
													target_means = target_means,           $
													tb_Factors = tb_factors,		           $
													months_used = months_used,             $
													date_L2C_processed = date_L2C_processed,  $
                          output_path = output_path
                          
;@***h* MLT_V4_RSS/write_amsu_only_merged_Tbs_144_72_netcdf_4_0
; NAME
;   write_amsu_only_merged_Tbs_144_72_netcdf_4_0
;
; PURPOSE
;   Writes results to an internal RSS netcdf file
;
; DESCRIPTION
;   Writes results to an internal RSS netcdf file
;   
; INPUTS
;   Tbs_144_72                fltarr array (144 x 72 x num_months) merged antenna temperatures
;   channel_str               string name of AMSU channel 
;   version_num               integer version num for file name
;   diurnal_model             string name of diurnal model
;   eia_model                 string name of earth incidence model
;   fov_wts                   fltarr array (30) weights for combining FOVs
;   node_wts                  fltarr array (2)  weights for combining ascending and descending nodes (usually [0.5,0.5])
;   adjustment_flag           integer flag describing adjustment level applied
;   offsets                   fltarr array (144 x 72 x num_sats) array of location dependent offsets
;   target_factors            fltarr array (144 x 72 x num_sats) array of location dependent target factors
;   target_means              fltarr array (num_sats) array of target means
;   tb_Factors                fltarr array (144 x 72 x num_sats) array of location dependent Tb factors (all zero)
;   months_used               intarr array (num_sats x num_months) set to 1 if sat/month used in final merge
;   date_L2C_processed        string date that the L2C files were processing
;   output_path               string path to write file
;   
; OUTPUTS
;   none
;   
; AUTHOR
;   Carl Mears, Remote Sensing Systems
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES,
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT
;   TO USERS.
;
; HISTORY
;   1/10/2018 Initial Version prepared for NCDC
;
; USAGE
;           write_amsu_only_merged_Tbs_144_72_netcdf_4_0,    $
;                      Tbs_144_72 = tb_arr_merged ,          $
;                      channel_str=channel_str,              $
;                      version_num=version_num,              $
;                      diurnal_model = diur__model_loaded,   $
;                      eia_model = eia__model_loaded,        $
;                      fov_wts = fov_wts,                    $
;                      node_wts = node_wts,                  $
;                      adjustment_flag = adj_flag,           $
;                      offsets = offset_arr,                 $  
;                      target_factors = tarmult_arr,         $ 
;                      tb_Factors = tbmult_arr,              $  
;                      target_means = target_means,          $  
;                      months_used = months_used,            $  
;                      output_path = output_path
;
;@*****


	fill_value = -9999.0
	sz = size(Tbs_144_72,/dimensions)
	num_lons = sz[0]
	num_lats = sz[1]
	num_months = sz[2]
	sz = size(offsets,/dimensions)
	num_satellites = sz[2]
	sz = size(fov_wts,/dimensions)
  num_fovs = sz[0]
	Tbs = Tbs_144_72
	bad = where(finite(Tbs) eq 0,ct)
	if ct gt 0 then begin
		Tbs[bad] = fill_value
	endif

	todays_date = current_date_string()

	nc_file = output_path + 'RSS_Tb_Maps_ch_'+channel_str+'_V4_0_'+string(version_num,format='(i7.7)')+'.nc'
	ok = check_path(nc_file,/create)
	log,'Info: NC file =',nc_file

	id = NCDF_CREATE(nc_file, /CLOBBER) ; Create the netCDF file.
	NCDF_ATTPUT, id, 'title', 'RSS Version 4.0 AMSU brightness temperatures', /GLOBAL
	NCDF_ATTPUT, id, 'institution', 'Remote Sensing Systems, Santa Rosa, CA, USA', /GLOBAL

	source_str = 'Advanced Microwave Sounding Unit (AMSU) satellite-borne microwave radiometer, channel '+channel_str

	a = SCOPE_TRACEBACK()
	main_program_name = a[0]

	NCDF_ATTPUT, id, 'source',  source_str, /GLOBAL
	NCDF_ATTPUT, id, 'history', todays_date + ' produced from version 4.0 RSS monthly maps for each AMSU instrument using the idl routine ' +main_program_name, /GLOBAL
	NCDF_ATTPUT, id, 'references', 'C. A. Mears, M. Schabel, and F. J. Wentz: A Reanalysis of the MSU Channel 2 Tropospheric Temperature Record, Journal of Climate 16, pp. 3650-3664', /GLOBAL

  node_str = 'Using '
  if node_wts[0] gt 0 then node_str = node_str + 'Ascending '
  if ((node_wts[0] gt 0) and (node_wts[1] gt 0)) then node_str = node_str + 'and '
  if node_wts[1] gt 0 then node_str = node_str + 'Descending '
  node_str = node_str + 'nodes'
	comment_str =  $
				'This is AMSU only data' + string(13B) + $
				'Data is from a restricted set of fields of view'+ string(13B)+ $
				node_str+string(13B)
	if (adjustment_flag and 4) gt 0 then begin
				comment_str = comment_str + 'Diurnal Model: '+diurnal_model+string(13B)
	endif else begin
	      comment_str = comment_str + 'No Diurnal Adjustment'+string(13B)
	endelse
	if (adjustment_flag and 3) gt 0 then begin
				comment_str = comment_str + 'EIA Model: '+eia_model+string(13B)
        if (adjustment_flag and 1) gt 0 then comment_str = comment_str + 'Corrected for incidence angle'+string(13B)
        if (adjustment_flag and 2) gt 0 then comment_str = comment_str + 'Corrected to nadir'+string(13B)
  endif else begin
        comment_str = comment_str + 'No EIA Adjustment'+string(13B)
  endelse
				  
	NCDF_ATTPUT, id, 'comment',comment_str , /GLOBAL

	x_dim      = NCDF_DIMDEF(id, 'longitude', num_lons) 		        ; Define the X dimension.
	x_edge_dim = NCDF_DIMDEF(id, 'longitude_bounds', num_lons+1) 	  ; Define the X dimension cell edges.
	y_dim      = NCDF_DIMDEF(id, 'latitude', num_lats) 		          ; Define the Y dimension.
	y_edge_dim = NCDF_DIMDEF(id, 'latitude_bounds', num_lats+1) 		; Define the Y dimension cell edges.
	time_dim   = NCDF_DIMDEF(id, 'months', num_months) 			 ; Define the month dimension.
	sat_dim    = NCDF_DIMDEF(id, 'satellites',num_satellites); Define the satellite number dimension
	fov_dim    = NCDF_DIMDEF(id, 'fov',num_fovs)             ; Define the field of view dimensions

	lon_id   			= NCDF_VARDEF(id, 'longitude', 			[x_dim], /FLOAT)
		NCDF_ATTPUT,id,lon_id,'long_name','longitude'
		NCDF_ATTPUT,id,lon_id,'units','degrees east'
		NCDF_ATTPUT,id,lon_id,'bounds','longitude_bounds'
	lat_id   			= NCDF_VARDEF(id, 'latitude', 			[y_dim], /FLOAT)
		NCDF_ATTPUT,id,lat_id,'long_name','latitude'
		NCDF_ATTPUT,id,lat_id,'units','degrees north'
		NCDF_ATTPUT,id,lat_id,'bounds','latitude_bounds'
	lon_boundary_id   	= NCDF_VARDEF(id, 'longitude_bounds', 	[x_edge_dim], /FLOAT)
		NCDF_ATTPUT,id,lon_boundary_id,'long_name','longitude_bounds'
		NCDF_ATTPUT,id,lon_boundary_id,'units','degrees east'
	lat_boundary_id   	= NCDF_VARDEF(id, 'latitude_bounds', 	[y_edge_dim], /FLOAT)
		NCDF_ATTPUT,id,lat_boundary_id,'long_name','latitude_bounds'
		NCDF_ATTPUT,id,lat_boundary_id,'units','degrees north'
	time_id 			= NCDF_VARDEF(id, 'months', 			[time_dim], /LONG)
		NCDF_ATTPUT,id,time_id,'long_name','time'
		NCDF_ATTPUT,id,time_id,'units','months since 1978-1-1 0:0:0'
	fov_wt_id     = NCDF_VARDEF(id, 'fov_wts',[fov_dim],/FLOAT)
    NCDF_ATTPUT,id,fov_wt_id,'long_name','field of view weights'
    NCDF_ATTPUT,id,fov_wt_id,'units','none'
	temperature_id  = NCDF_VARDEF(id, 'brightness_temperature',[x_dim,y_dim,time_dim], /FLOAT)
		NCDF_ATTPUT,id,temperature_id,'long_name','monthly averaged single channel brightness temperature'
		NCDF_ATTPUT,id,temperature_id,'units','degrees K'
		NCDF_ATTPUT,id,temperature_id,'_FillValue',fill_value
	months_used_id  = NCDF_VARDEF(id, 'satellites_used',[sat_dim,time_dim], /BYTE)
	  NCDF_ATTPUT,id,months_used_id,'long_name','satellites used by month'
		NCDF_ATTPUT,id,months_used_id,'units','none'
		NCDF_ATTPUT,id,months_used_id,'comment','1 when satellite used, 0 otherwise'
	offset_id		= NCDF_VARDEF(id, 'offset_values',[x_dim,y_dim,sat_dim],/FLOAT)
		NCDF_ATTPUT,id,offset_id,'long_name','satellite calibration offset for each latitude'
		NCDF_ATTPUT,id,offset_id,'units','degrees K'
	target_factor_id= NCDF_VARDEF(id,'target_factor_values',[x_dim,y_dim,sat_dim],/FLOAT)
		NCDF_ATTPUT,id,target_factor_id,'long_name','satellite calibration target factor for each latitude'
		NCDF_ATTPUT,id,target_factor_id,'units','dimensionless'
	tb_factor_id= NCDF_VARDEF(id,'tb_factor_values',[x_dim,y_dim,sat_dim],/FLOAT)
		NCDF_ATTPUT,id,target_factor_id,'long_name','satellite calibration tb factor for each latitude'
		NCDF_ATTPUT,id,target_factor_id,'units','dimensionless'
	target_mean_id = NCDF_VARDEF(id,'target_means',[sat_dim],/FLOAT)
	  NCDF_ATTPUT,id,target_factor_id,'long_name','satellite mean target temperature'
    NCDF_ATTPUT,id,target_factor_id,'units','K'

	; switch to data mode and write data

	NCDF_CONTROL, id, /ENDEF ; Put the file into data mode.

	latitude   		= (indgen(num_lats)*2.5) -90.0+1.25
	longitude  		= 1.25 +(indgen(num_lons) * 2.5)
	latitude_bnd   	= (indgen(num_lats+1)*2.5) -90.0
	longitude_bnd  	= indgen(num_lons+1) * 2.5
	months      	= indgen(num_months)+240

	NCDF_VARPUT, id, lon_id, longitude
	NCDF_VARPUT, id, lat_id, latitude
	NCDF_VARPUT, id, lon_boundary_id, longitude_bnd
	NCDF_VARPUT, id, lat_boundary_id, latitude_bnd
	NCDF_VARPUT, id, time_id, months
	NCDF_VARPUT, id, fov_wt_id,fov_wts
	NCDF_VARPUT, id, temperature_id, Tbs
	NCDF_VARPUT, id, months_used_id, transpose(months_used)
	NCDF_VARPUT, id, offset_id,offsets
	NCDF_VARPUT, id, target_factor_id,target_factors
	NCDF_VARPUT, id, tb_factor_id,tb_factors
	NCDF_VARPUT, id, target_mean_id,target_means


	NCDF_CLOSE, id ; Close the NetCDF file.

end
